<?php 

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

/**
 * Admin Class
 *
 * Handles admin side plugin functionality.
 *
 * @package WooCommerce WP Social Deals
 * @since 1.0.0
 */
class Wpsd_Admin{
	
	var $render,$model;
	
	public function __construct() {
		
		global $wpsd_render,$wpsd_model;
		
		$this->render = $wpsd_render;
		$this->model = $wpsd_model;
	}
	
	/**
	 * Main entry point.
	 *
	 * @static
	 */
	public static function serve() {
	
		$me = new Wpsd_Admin();
		$me -> add_hooks();
	}
		
	/**
	 * Save Metabox Data
	 * 
	 * Handles to save metabox details
	 * to database
	 *
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	public function product_save_data( $post_id, $post ) {
		
		$product_type = $this->model->wpsd_get_product_type( $post_id );
		
		update_post_meta( $post_id, '_wpsd_enable', ( $_POST['_wpsd_enable'] ) );
		
		update_post_meta( $post_id, '_wpsd_expired_deals', ( $_POST['_wpsd_expired_deals'] ) );
		
		if( strtolower($product_type) == 'variable' || strtolower($product_type) == 'grouped' ) { // check product type is variable or grouped
			
			$start_date = $end_date = '';
			
			//check start date is set or not
			if( isset($_POST['_wpsd_start_date']) && !empty($_POST['_wpsd_start_date']) ) {
				$start_date = strtotime( $_POST['_wpsd_start_date'] );
			}
			update_post_meta( $post_id, '_wpsd_start_date', $start_date );
			update_post_meta( $post_id, '_sale_price_dates_from', $start_date );
			
			//check end date is set or not
			if( isset($_POST['_wpsd_end_date']) && !empty($_POST['_wpsd_end_date']) ) {
				$end_date = strtotime( $_POST['_wpsd_end_date'] );
			}
			update_post_meta( $post_id, '_wpsd_end_date', $end_date );
			update_post_meta( $post_id, '_sale_price_dates_to', $end_date );
		}
		
		//Update deal main image
		update_post_meta( $post_id, '_wpsd_main_image', $_POST['_wpsd_main_image'] );
		
		//check show deal on home page is set in metabox or not
		if( isset($_POST['_wpsd_home_page']) ) {
			update_post_meta( $post_id, '_wpsd_home_page', stripslashes( $_POST['_wpsd_home_page'] ) );
		}
		
		//check increasable price is set or not
		if( isset($_POST['_wpsd_inc_price']) ) {
			update_post_meta( $post_id, '_wpsd_inc_price', stripslashes( $_POST['_wpsd_inc_price'] ) );
		}
		//check increasable ratio is set or not
		if( isset($_POST['_wpsd_inc_ratio']) ) {
			update_post_meta( $post_id, '_wpsd_inc_ratio', stripslashes( $_POST['_wpsd_inc_ratio'] ) );
		}
		//check purchase link is set or not
		if( isset($_POST['_wpsd_purchase_link']) ) {
			update_post_meta( $post_id, '_wpsd_purchase_link', stripslashes( $_POST['_wpsd_purchase_link'] ) );
		}
		
		update_post_meta( $post_id, '_wpsd_claim_offer_link', ( $_POST['_wpsd_claim_offer_link'] ) );
		//check offer title is set or not
		if( isset($_POST['_wpsd_claim_offer_title']) ) {
			update_post_meta( $post_id, '_wpsd_claim_offer_title', stripslashes( $_POST['_wpsd_claim_offer_title'] ) );
		}
		//check claim offer content is set or not
		if( isset($_POST['_wpsd_claim_offer_content']) ) {
			update_post_meta( $post_id, '_wpsd_claim_offer_content', stripslashes( $_POST['_wpsd_claim_offer_content'] ) );
		}
		//check add to cart text is set or not
		if( isset($_POST['_wpsd_add_to_cart']) ) {
			update_post_meta( $post_id, '_wpsd_add_to_cart', stripslashes( $_POST['_wpsd_add_to_cart'] ) );
		}
		
		update_post_meta( $post_id, '_wpsd_available_bought', ( $_POST['_wpsd_available_bought'] ) );
		
		//check business title is set or not
		if( isset($_POST['_wpsd_business_title']) ) {
			update_post_meta( $post_id, '_wpsd_business_title', stripslashes( $_POST['_wpsd_business_title'] ) );
		}
		//check business logo is set or not
		if( isset($_POST['_wpsd_business_logo']) ) {
			update_post_meta( $post_id, '_wpsd_business_logo', ( $_POST['_wpsd_business_logo'] ) );
		}
		//check business address is set or not
		if( isset($_POST['_wpsd_business_address']) ) {
			update_post_meta( $post_id, '_wpsd_business_address', stripslashes( $_POST['_wpsd_business_address'] ) );
		}
		//check business website url is set or not
		if( isset($_POST['_wpsd_business_web_url']) ) {
			update_post_meta( $post_id, '_wpsd_business_web_url', stripslashes( $_POST['_wpsd_business_web_url'] ) );
		}
		//check business map is set or not
		if( isset($_POST['_wpsd_map_address']) ) {
			update_post_meta( $post_id, '_wpsd_map_address', stripslashes( $_POST['_wpsd_map_address'] ) );
		}
		//check map popup width is set or not
		if( isset($_POST['_wpsd_map_popup_width']) ) {
			update_post_meta( $post_id, '_wpsd_map_popup_width', stripslashes( $_POST['_wpsd_map_popup_width'] ) );
		}
		//check map popup content is set or not
		if( isset($_POST['_wpsd_popup_content']) ) {
			update_post_meta( $post_id, '_wpsd_popup_content', stripslashes( $_POST['_wpsd_popup_content'] ) );
		}
		//check terms and conditions is set or not
		if( isset($_POST['_wpsd_term_cond']) ) {
			update_post_meta( $post_id, '_wpsd_term_cond', stripslashes( $_POST['_wpsd_term_cond'] ) );
		}
		//check social sharing discount link title is set or not
		if( isset($_POST['_wpsd_sharing_discount_link_title']) ) {
			update_post_meta( $post_id, '_wpsd_sharing_discount_link_title', stripslashes( $_POST['_wpsd_sharing_discount_link_title'] ) );
		}
		//check social sharing discount title is set or not
		if( isset($_POST['_wpsd_sharing_discount_title']) ) {
			update_post_meta( $post_id, '_wpsd_sharing_discount_title', stripslashes( $_POST['_wpsd_sharing_discount_title'] ) );
		}
		//check social sharing discount content is set or not
		if( isset($_POST['_wpsd_sharing_discount_content']) ) {
			update_post_meta( $post_id, '_wpsd_sharing_discount_content', stripslashes( $_POST['_wpsd_sharing_discount_content'] ) );
		}
		//check social sharing discount for facebook is set or not
		if( isset($_POST['_wpsd_fb_discount']) ) {
			update_post_meta( $post_id, '_wpsd_fb_discount', stripslashes( $_POST['_wpsd_fb_discount'] ) );
		}
		//check social sharing discount for facebook fanpage is set or not
		if( isset($_POST['_wpsd_fan_page_discount']) ) {
			update_post_meta( $post_id, '_wpsd_fan_page_discount', stripslashes( $_POST['_wpsd_fan_page_discount'] ) );
		}
		//check social fanpage link is set or not
		if( isset($_POST['_wpsd_fan_page_link']) ) {
			update_post_meta( $post_id, '_wpsd_fan_page_link', stripslashes( $_POST['_wpsd_fan_page_link'] ) );
		}
		//check social discount for twitter is set or not
		if( isset($_POST['_wpsd_tw_discount']) ) {
			update_post_meta( $post_id, '_wpsd_tw_discount', stripslashes( $_POST['_wpsd_tw_discount'] ) );
		}
		//check social sharing discount for google+ is set or not
		if( isset($_POST['_wpsd_gp_discount']) ) {
			update_post_meta( $post_id, '_wpsd_gp_discount', stripslashes( $_POST['_wpsd_gp_discount'] ) );
		}
		//check next period of dimsale counter is set or not if not then set it to zero
		if( !get_post_meta( $post_id, '_wpsd_nxt_inc_period', true)) {
			update_post_meta( $post_id, '_wpsd_nxt_inc_period', '0');
		}
		
	}
	
	/**
	 * WooCommerce init
	 * 
	 * Handles init functionalities to 
	 * adding metabox tabs and settings array
	 * will be generated from below function
	 *
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	public function init() {
		
		global $deals_options;
		
		// backend action
		add_action( 'woocommerce_product_write_panel_tabs', array( $this->render, 'product_write_panel_tab' ) );
		add_action( 'woocommerce_product_write_panels',     array( $this->render, 'product_write_panel' ) );
		add_action( 'woocommerce_process_product_meta',     array( $this, 'product_save_data' ), 20, 2 );
		
		//get all pages					
		$get_pages = get_pages(); 
		
		//get all pages created on activation
		$allpagescreated = get_option( 'wpsd_set_pages' ); 
		
		$all_pages = array();
		foreach ($get_pages as $page) {
			$all_pages[$page->ID] = $page->post_title;
		}
		
		$deals_options =  array(
									array (
											'title' 	=> __( 'Deals Options', 'wpsd' ),
											'type' 		=> 'title',
											'desc'		=> '',
											'id' 		=> 'deals_options'
								         ),
									array (
											'title' 	=> __( 'Deals Home Page:', 'wpsd' ),
											'type' 		=> 'select',
											'options'	=> $all_pages,
											'default'	=> $allpagescreated['main_page'],
											'desc_tip'	=> __( 'This is the deals home/overview page where visitors can see all deals.', 'wpsd' ),
											'id' 		=> 'deals_main_page'
								         ),
									array (
											'title' 	=> __( 'Size:', 'wpsd' ),
											'type' 		=> 'select',
											'default' 	=> 'large',
											'options'	=> array(
																		'small'	=> __( 'Small', 'wpsd' ),
																		'medium'=> __( 'Medium', 'wpsd' ),
																		'large'	=> __( 'Large', 'wpsd' )
																	),
											'desc_tip'	=> __( 'Choose the size for the deals. This will then use different sizes for the fonts and spacing, so that they fit in to your theme.', 'wpsd' ),
											'id' 		=> 'deals_size'
								         ),
									array (
											'title' 	=> __( 'Caching:', 'wpsd' ),
											'type' 		=> 'checkbox',
											'default' 	=> 'no',
											'desc_tip'	=> __( 'Check this box, if you use a caching plugin. For more information visit  our <a href="http://wpsocial.com/knowledgebase/" target="_blank">Knowledge Base</a>', 'wpsd' ),
											'id' 		=> 'deals_caching'
								         ),
									array (
											'title' 	=> __( 'Disable Twitter Bootstrap:', 'wpsd' ),
											'type' 		=> 'checkbox',
											'default' 	=> 'no',
											'desc_tip'	=> __( 'Check this box, if your theme does already include the Twitter Bootstrap framework.', 'wpsd' ),
											'id' 		=> 'disable_twitter_bootstrap'
								         ),
									array (
											'title' 	=> __( 'Disable More Deals:', 'wpsd' ),
											'type' 		=> 'checkbox',
											'default' 	=> 'no',
											'desc_tip'	=> __( 'Check this box, if you don\'t want to display the Active, Ending Soon and Upcomming Deals on your deals home/overview page.', 'wpsd' ),
											'id' 		=> 'disable_more_deals'
								         ),
									array (
											'title' 	=> __( 'Ending Deals:', 'wpsd' ),
											'type' 		=> 'text',
											'class' 	=> 'small-text',
											'desc_tip'	=> __( 'Enter a number of days here. If you enter 2 as example, then all deals which will end within 2 days will be displayed within the "Ending Soon" tab.', 'wpsd' ),
											'id' 		=> 'ending_deals_in'
								         ),
									array (
											'title' 	=> __( 'Upcoming Deals:', 'wpsd' ),
											'type' 		=> 'text',
											'class' 	=> 'small-text',
											'desc_tip'	=> __( 'Enter a number of days here. If you enter 2 as example, then all deals which will start within 2 days will be displayed within the "Upcoming Deals" tab.', 'wpsd' ),
											'id' 		=> 'upcoming_deals_in'
								         ),
									array (
											'title' 	=> __( 'Deals Per Page:', 'wpsd' ),
											'type' 		=> 'text',
											'class' 	=> 'small-text',
											'desc_tip'	=> __( 'Enter the number of deals you want to display.', 'wpsd' ),
											'id' 		=> 'deals_per_page'
								         ),
									array (
											'title' 		=> __( 'Social Connect Buttons:', 'wpsd' ),
											'type' 			=> 'checkbox',
											'default' 		=> 'no',
											'checkboxgroup' => 'start',
											'desc'			=> __( 'Facebook', 'wpsd' ),
											'id' 			=> 'social_buttons_facebook'
								         ),
									array (
											'type' 			=> 'checkbox',
											'default' 		=> 'no',
											'checkboxgroup' => '',
											'desc'			=> __( 'Twitter', 'wpsd' ),
											'id' 			=> 'social_buttons_twitter'
								         ),
									array (
											'type' 			=> 'checkbox',
											'default' 		=> 'no',
											'checkboxgroup' => '',
											'desc'			=> __( 'Google+', 'wpsd' ),
											'id' 			=> 'social_buttons_google' 
								         ),
									array (
											'type' 			=> 'checkbox',
											'default' 		=> 'no',
											'checkboxgroup' => 'end',
											'desc'			=> __( 'Fan Page Like', 'wpsd' ),
											'desc_tip'		=> __( 'Choose which social sharing buttons you want to display.', 'wpsd' ),
											'id' 			=> 'social_buttons_fanpage'
								         ),
									array (
											'title' 	=> __( 'Twitter User Name:', 'wpsd' ),
											'type' 		=> 'text',
											'class'		=> 'regular-text',
											'desc_tip'	=> __( 'Enter your Twitter user name.', 'wpsd' ),
											'id' 		=> 'tw_user_name'
								         ),
									array (
											'title' 	=> __( 'Fan Page Like URL:', 'wpsd' ),
											'type' 		=> 'text',
											'class'		=> 'regular-text',
											'desc_tip'	=> __( 'Enter the URL to your Facebook Fan Page.', 'wpsd' ),
											'id' 		=> 'fan_page_url'
								         ),
								 	array(
											'type' 		=> 'sectionend',
											'id' 		=> 'deals_options'
								 	)
							 	);
		
	}
	
	/**
	 * Settings Tab
	 * 
	 * Handels to add settings tab 
	 * in settings page of woocommerce
	 *
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	public function settings_tabs_array( $tabs ) {
		
		$tabs['deals'] = __( 'Deals', 'wpsd' );
		
		return $tabs;
	}
	
	/**
	 * Settings tab content
	 * 
	 * Handles to add tab content in
	 * settings page
	 *
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	public function settings_tabs_deals() {
		
		global $deals_options;
		//check deals options is set or not
		if ( isset( $deals_options ) )
			woocommerce_admin_fields( $deals_options ); 

	}
	
	/**
	 * Settings Save
	 * 
	 * Handles to save settings page 
	 * options to database
	 *
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	public function update_options_deals() {
		
		global $deals_options;
		//check deals options is set or not
		if ( isset( $deals_options ) )
			woocommerce_update_options( $deals_options );
		
	}
	
	/**
	 * Adding Hooks
	 *
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	public function add_hooks() {
		
		add_action( 'woocommerce_init', array( $this, 'init' ) );
		
		add_filter( 'woocommerce_settings_tabs_array', array( $this, 'settings_tabs_array' ), 10, 1 );
		
		add_action( 'woocommerce_settings_tabs_deals', array( $this, 'settings_tabs_deals' ) );
		
		add_action( 'woocommerce_update_options_deals', array( $this, 'update_options_deals' ), 100 );
		
	}
}
?>