<?php

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

/**
 * Price Class
 *
 * Handles all the different functionalities related prices
 *
 * @package WooCommerce WP Social Deals
 * @since 1.0.0
 */

class Wpsd_Price{
	
	var $model;
	public function __construct() {
		
		global $wpsd_model;
		
		$this->model = $wpsd_model;
	}
	
	/**
	 * Get Product Price
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	public function wpsd_get_price($normalprice, $saleprice) {
		
		$price = '';
		if(!empty($saleprice)) {
			$price = $saleprice;
		} else {
			$price = $normalprice;
		}
		return apply_filters('wpsd_sale_price',$price);
	}
	
	/**
	 * Get Saving Price
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	public function wpsd_get_savingprice($normalprice, $saleprice) {
		
		if(isset( $normalprice )  && !empty( $normalprice ) && isset( $saleprice )  && !empty( $saleprice ) ) {
			$save_price = ( $normalprice - $saleprice );
		} else {
			$save_price = '0.00';
		}
		$yousave = $this->wpsd_get_display_price($save_price);
		return $yousave;
	}
	
	/**
	 * Get Discount Value
	 * 
	 * Handles to return discounted precentage
	 * which will see by user on deal page 
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	public function wpsd_get_discount($normalprice, $saleprice) {
		//check normal price and sale price is set and not empty
		if(isset( $normalprice )  && !empty( $normalprice ) && isset( $saleprice )  && !empty( $saleprice ) ) {
			$save_price = ( $normalprice - $saleprice );
			$save_percent = ( $save_price * 100 ) / $normalprice;
			$save_percent = round( $save_percent );
			$discount = $save_percent.'%';
		} else {
			$discount = '0%';
		}
		
		return $discount;
	}
	
	/**
	 * Display Price 
	 * 
	 * Handles to return disaplay price of 
	 * product when deal is enabaled for
	 * this product
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 * 
	 */
	public function wpsd_get_display_price($price){
		
		$currency_symbol = get_woocommerce_currency_symbol();
		
		//filter to change price with taxes
		if (empty($price)) $price = 0.00;
		
		$price = number_format($price, 2);
		
		return $currency_symbol . ' ' . $price;
	}
	
	/**
	 * Normal Price 
	 * 
	 * Handles to return disaplay normal price of 
	 * product when woocommerce product type different
	 * this product
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 * 
	 */
	public function wpsd_get_normal_price() {

		global $product;
		
		$normal_price = '';
	
		if( strtolower($product->product_type) == 'grouped' ) { //if product type is grouped
			$normal_price = $product->get_price();
		} else if( strtolower($product->product_type) == 'variable' ) { //if product type is variable
			
			$variation_id = $this->model->wpsd_get_default_variation_id();
			if( !empty( $variation_id ) ) {
				// get the value for variation regular price from the post meta box	
				$normal_price = get_post_meta( $variation_id, '_regular_price', true );
			} else {
				// get the value for min variation regular price from the post meta box	
				$normal_price = $product->min_variation_regular_price;
			}
			
		} else {
			//else take regular price of product
			$normal_price = $product->regular_price;
		}
		
		return $normal_price;
	}
	
	/**
	 * Future Sale Price 
	 * 
	 * Handles to return disaplay normal price of 
	 * product when woocommerce product type different
	 * this product
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 * 
	 */
	public function wpsd_get_future_sale_price() {

		global $product;
		
		$price = '';
	
		$today = date_i18n('Y-m-d H:i:s');
		$today = strtotime( $today );
			
		$upcoming_deals_in = get_option('upcoming_deals_in');
					
		//get upcoming deals days from settings page
		$upcoming_days = !empty($upcoming_deals_in) ? $upcoming_deals_in : 0;
		$upcoming_deal_days = date_i18n('Y-m-d H:i:s', strtotime('+'.$upcoming_days.' days'));
		$upcoming_deal_days = strtotime( $upcoming_deal_days );
		
		$start_date = $this->model->wpsd_get_start_date( $product->id );
		$start_date = strtotime( $start_date );
		
		if( $start_date <= $upcoming_deal_days && $start_date > $today ) { // Check Upcoming deal
			
			$variation_id = $this->model->wpsd_get_default_variation_id();
			//if product type is variable
			if( strtolower($product->product_type) == 'variable' ) {
				if( !empty($variation_id) ) {
					// get the value for variation sale price from the post meta box	
					$price = get_post_meta( $variation_id, '_price', true );
				} else {
					// get the value for min variation sale price from the post meta box	
					$price = $product->min_variation_price;
				}
			} else {
				// get the value for sale price from the post meta box	
				$price = get_post_meta( $product->id, '_sale_price', true );
			}
			
		} else {
			$price = $product->get_price();
		}
		
		return $price;
	}
	
}
?>