<?php

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

/**
 * Public Class
 *
 * Handles all public functionalities of plugin
 *
 * @package WooCommerce WP Social Deals
 * @since 1.0.0
 */
class Wpsd_Public{
	
	var $render;
	var $model;
	var $price;
	public function __construct() {
		
		global $wpsd_render, $wpsd_model, $wpsd_price;
		$this->render = $wpsd_render;
		$this->model = $wpsd_model;
		$this->price = $wpsd_price;
		
	}
	
	/**
	 * Main entry point.
	 *
	 * @static
	 */
	public static function serve() {
		
		$me = new Wpsd_Public();
		$me -> add_hooks();
	}
	
	/**
	 * Load Business Details Template
	 * 
	 * Business Detail Template
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 * 
	 */
	public function after_single_product_summary() {
				
		echo '<div class="clear"></div>';
		
		wpsd_get_template( '/single-deal/single-footer.php' );
		
	}
	
	/**
	 * Load template on single product page
	 * 
	 * Handles to load templates for
	 * Left Deals Text, Deal Details, Deal End Timer Templates
	 * on single product page
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 * 
	 */
	public function single_product_summary() {
				
		do_action( 'wpsd_single_header_right' ); 
		
	}
	
	/**
	 * Load Add to Cart Template
	 * 
	 * Handle load add to cart button template
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 * 
	 */
	public function single_add_to_cart() {
		
		wpsd_get_template( '/single-deal/add-to-cart.php' );
		
	}
	
	/**
	 * Return Stock Qunatity
	 * 
	 * Handle show quantity HTML of product
	 * as per deal is enabled or not on that product
	 * if deal is enabled then hide quantity
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 * 
	 */
	public function stock_html( $html, $availability ) {
		
		global $post, $product;
			
		// check available stock 
		$avail_stock = $product->is_in_stock();
		
		if( !$avail_stock && strtolower($product->product_type) != 'grouped' ) { //when product is out of stock and product type is not grouped
			
			ob_start();
			wpsd_get_template( 'single-deal/deal-expired.php');
			$html = ob_get_clean();
			
		} else {
			
			$html = '';
		}
			
		return $html;
		
	}
	
	/**
	 * Add to cart text
	 * 
	 * Handles to change add to cart button
	 * text of product
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 * 
	 */
	public function single_add_to_cart_text( $text, $product_type) {
		
		global $post, $product;
	
		if( strtolower($product_type) != 'external' && strtolower($product_type) != 'grouped' ) {
				
			$variation_id = $this->model->wpsd_get_default_variation_id();
			
			if( !empty($variation_id) ) {
				
				// get the value for variation normal price from the post meta box
				$normalprice = get_post_meta( $variation_id, '_regular_price', true );
				
				// get the value for variation sale price from the post meta box	
				$saleprice = get_post_meta( $variation_id, '_price', true );
				
			} else {
				
				// get the value for normal price from the post meta box
				$normalprice = $this->price->wpsd_get_normal_price();
				
				// get the value for sale price from the post meta box	
				$saleprice = $product->get_price();
			}
			
			//product price 
			$productprice = $this->price->wpsd_get_price($normalprice, $saleprice);
			
			$productprice = $this->price->wpsd_get_display_price($productprice);
		
			//get add to cart button 
			$addtocart_post = get_post_meta($post->ID,'_wpsd_add_to_cart',true);
			if( !empty( $addtocart_post ) ) {
				$addcartbtntext = $addtocart_post;
			} else {
				$addcartbtntext = __('Add to Cart', 'wpsd');
			}
			
			return $addcartbtntext . ' <span class="wpsd-add-to-cart-price">' . $productprice . '</span>'; 
			
		} else {
			
			return $text;
		}
	}
	
	/**
	 * Available Variation 
	 * 
	 * Handles to customize available variation 
	 * text of product
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 * 
	 */
	public function wpsd_available_variation( $available_variations, $product, $variation ) {
		
		global $post;
		
		$product_type = $this->model->wpsd_get_product_type( $post->ID );
		if( strtolower($product_type) == 'variable' && isset($available_variations['variation_id']) && !empty($available_variations['variation_id']) ) {
			
			$variation_id = $available_variations['variation_id']; // variation id
			
			$variation_normal_price = get_post_meta( $variation_id, '_regular_price', true ); // variation normal price
			$variation_sale_price 	= get_post_meta( $variation_id, '_price', true ); // variation final sale price
			
			$yousave = $this->price->wpsd_get_savingprice( $variation_normal_price, $variation_sale_price );
			$discount = $this->price->wpsd_get_discount( $variation_normal_price, $variation_sale_price );
			
			$available_variations['price_html']		= '';
			$available_variations['normalprice']	= $this->price->wpsd_get_display_price( $variation_normal_price );
			$available_variations['saleprice']		= $this->price->wpsd_get_display_price( $variation_sale_price );
			$available_variations['discount'] 		= $discount;
			$available_variations['yousave'] 		= $yousave;
			
		}
		return $available_variations;
	}
	
	/**
	 * AJAX Call
	 * 
	 * Handles to ajax call to store social count to the database
	 * 
	 * @package WooCommerce WPSocial Deals
	 * @since 1.0.0
	 * 
	 */
	public function wpsd_update_social_count() {
		
		if(isset($_POST['postid']) && !empty($_POST['postid'])) { //check post id is not empty or not
			
			$type = $_POST['type'];
			$postid = $_POST['postid'];
			
			if($type == 'fb') { //if facebook 
				
				$fbcount = get_post_meta( $postid, '_wpsd_social_fb_count', true );
				$fbcount = !empty($fbcount) ? $fbcount : '0';
				$fbcount += 1;
				update_post_meta( $postid, '_wpsd_social_fb_count', $fbcount );
				
			} elseif ($type == 'tw') {
				
				$twcount = get_post_meta( $postid, '_wpsd_social_tw_count', true );
				$twcount = !empty($twcount) ? $twcount : '0';
				$twcount += 1;
				update_post_meta( $postid, '_wpsd_social_tw_count', $twcount );
				
			} elseif ($type == 'gp') { //google plus button
				
				$gpcount = get_post_meta( $postid, '_wpsd_social_gp_count', true );
				$gpcount = !empty($gpcount) ? $gpcount : '0';
				$gpcount += 1;
				update_post_meta( $postid, '_wpsd_social_gp_count', $gpcount );
				
			} elseif ($type == 'fan') { //fan page like button
				
				$fanpagecount = get_post_meta( $postid, '_wpsd_social_fan_page_count', true );
				$fanpagecount = !empty($fanpagecount) ? $fanpagecount : '0';
				$fanpagecount += 1;
				update_post_meta( $postid, '_wpsd_social_fan_page_count', $fanpagecount );
				
			} 
			
			//do action to do update social media data
			do_action('wpsd_update_social_data',$postid,$type);
		}
		exit;
		
	}
	
	/**
	 * Load Page Template
	 * 
	 * Handles to load page template for deals pages
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 * 
	 */
	public function wpsd_load_template( $template ) {
		
		$dealsshoppage = get_option( 'deals_main_page' );
		 
		$find = array( 'woocommerce_wpsocial_deals.php' );
		$file = '';
		
		if ( is_post_type_archive( WPSD_POST_TYPE ) || is_page( $dealsshoppage ) ) { //check it is deals shop page

			$file 	= 'home-deals.php';
			$find[] = $file;
			$find[] = WPSD_PLUGIN_BASENAME . '/' . $file;

		}
		
		if ( $file ) {
			$template = locate_template( $find );
			if ( ! $template ) $template = wpsd_get_templates_dir() . $file;
		}
		
		return $template;
	}
	/**
	 * Work with Dim Sale
	 * 
	 * Handles to update sale price when proper
	 * ratio and values
	 * 
	 * @package Wo
	 */
	public function wpsd_increase_sale_price( $orderid ) {
		
		if( class_exists( 'WC_Order' ) ) {
			
			$woorders = new WC_Order( $orderid );
			$productdetails = $woorders->get_items();
			
			foreach ( $productdetails as $key => $value ) {
				
				// single product id
				$dealid = $value['product_id']; // array_shift( $value['item_meta']['_product_id'] );
				
				// variation product id
				$variationid = $value['variation_id']; // array_shift( $value['item_meta']['_variation_id'] );
				
				if( !empty($variationid) ) { // if variation id is not empty
					$productid = $variationid;
				} else {
					$productid = $dealid;
				}
				
				//today's date time
				$today = date_i18n('Y-m-d H:i:s');
				
				$enddate = $this->model->wpsd_get_end_date( $dealid );
				
				$enabledeals = get_post_meta( $dealid, '_wpsd_enable', true );
				
				$expireddeals = get_post_meta( $dealid, '_wpsd_expired_deals', true );
				
				//check deal is enable for particular product
				if( !empty( $enabledeals ) && ( $enddate >= $today || !empty( $expireddeals ) ) ) {
				
					//increaseable price
					$incprice = get_post_meta( $dealid, '_wpsd_inc_price', true);
					
					//increaseable ratio
					$ratio = get_post_meta( $dealid, '_wpsd_inc_ratio', true);
					
					if( !empty($incprice) && !empty($ratio) ) {
						
						$dealqty = array_shift( $value['item_meta']['_qty'] );
						
						//when next price will increase
						$lastless = get_post_meta( $dealid, '_wpsd_nxt_inc_period', true);
						$saleqty = $lastless + $dealqty;
						$incloop = intval(  $saleqty / $ratio);
						$incless = (  $saleqty % $ratio);
					
						if($incloop > 0) { // check next loop is greater zero
							
							for ($i = 1; $i <= $incloop; $i++) {
								
								// get the value for deal price from the post meta box
								$normalprice = get_post_meta( $productid,'_regular_price',true );
									
								// get the value for deal sale price from the post meta box
								$saleprice = get_post_meta( $productid,'_sale_price',true );
								
								//increased price
		 						$increprice = floatval( $saleprice + $incprice );
		 						
								//if sale price should be less or equal to normal price then only increase price
		 						if( $increprice <= $normalprice ) {
									//update sale price
									update_post_meta( $productid, '_sale_price', $increprice );
									update_post_meta( $productid, '_price', $increprice );
		 						}
							}
						
						}
						//update next increment period value
						update_post_meta( $dealid, '_wpsd_nxt_inc_period', $incless);
					}
				}
				
			}
			
		}
	}
	
	/**
	 * Set Cookie for Social Discount
	 * 
	 * Handles to set social discount cookie
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	public function wpsd_set_social_discount_applied($dealid,$type) {
		
		if(isset($dealid) && !empty($dealid)) { //check post id is not empty or not
			
			if( $type == 'fb' ) { //facebook like discount cookie
				setcookie('wpsd_social_disc_fb_'.$dealid, true, time()+ (60*60*24), '/' );  /* expire in 1 day */
				echo '1'; 
			} elseif ( $type == 'tw' ) { //twitter discount cookie
				setcookie('wpsd_social_disc_tw_'.$dealid, true, time()+ (60*60*24), '/' );  /* expire in 1 day */
				echo '1';
			} elseif ( $type == 'gp' ) { //google+ discount cookie
				setcookie('wpsd_social_disc_gp_'.$dealid, true, time()+ (60*60*24), '/' );  /* expire in 1 day */
				echo '1';
			} elseif ( $type == 'fan' ) { //fan page like discount cookie
				setcookie('wpsd_social_disc_fan_'.$dealid, true, time()+ (60*60*24), '/' );  /* expire in 1 day */
				echo '1';
			}
		}
	}
	
	/**
	 * Change sale price
	 * 
	 * Handles to change sale price
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 * 
	 */
	public function wpsd_get_price($price, $product) {
		
		global $post;
		 
		$dealid = $product->id;
		
		$fbdisprice = get_post_meta( $dealid, '_wpsd_fb_discount', true ); //facebook like discount
		$twdisprice = get_post_meta( $dealid, '_wpsd_tw_discount', true ); //twitter tweet discount
		$gpdisprice = get_post_meta( $dealid, '_wpsd_gp_discount', true ); //google+ like discount
		
		$discount = 0;
		
		if( (isset($_COOKIE['wpsd_social_disc_fb_'.$dealid]) && !empty($_COOKIE['wpsd_social_disc_fb_'.$dealid])) 
			&& !empty($fbdisprice)) {
			
			//$price = $price - $fbdisprice;
			$discount += $fbdisprice;
		}
		if (isset($_COOKIE['wpsd_social_disc_tw_'.$dealid]) && !empty($_COOKIE['wpsd_social_disc_tw_'.$dealid])
				  && !empty($twdisprice)) {
			
			//$price = $price - $twdisprice;
			$discount += $twdisprice;
			
		} 
		if (isset($_COOKIE['wpsd_social_disc_gp_'.$dealid]) && !empty($_COOKIE['wpsd_social_disc_gp_'.$dealid])
				 && !empty($twdisprice)){
			
			//$price = $price - $gpdisprice;
			$discount += $gpdisprice;
		}		
		if (isset($_COOKIE['wpsd_social_disc_fan_'.$dealid]) && !empty($_COOKIE['wpsd_social_disc_fan_'.$dealid])
				 && !empty($fandisprice)){
			
			$discount += $fandisprice;
		}
		
		if($discount > $price) { //if discount is greater then price
			$price = 0;
		} else {
			$price = $price - $discount;
		}
		
		return $price;
		
	}
	
	public function wpsd_load_deals_actions() {
		
		global $post;
		
		if( !is_admin() ) { // check this is not admin 
			
			//today's date time
			$today = date_i18n('Y-m-d H:i:s');
			
			$enddate = $this->model->wpsd_get_end_date( $post->ID );
			
			$enabledeals = get_post_meta( $post->ID, '_wpsd_enable', true );
			
			$expireddeals = get_post_meta( $post->ID, '_wpsd_expired_deals', true );
			
			//check deal is enable for particular product
			if( !empty( $enabledeals ) && ( $enddate >= $today || !empty( $expireddeals ) ) ) {
			
				// Business details action
				add_action('woocommerce_after_single_product_summary', array($this, 'after_single_product_summary'), 5);
				 
				// remove action for display template price
				remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_price', 10 ); 
				
				// Left Deals Text, Deal Details, Deal End Timer Template action
				add_action('woocommerce_single_product_summary', array($this, 'single_product_summary'), 10 ); 
				
				// Handle Add to cart action
				add_action('woocommerce_single_product_summary', array($this, 'single_add_to_cart'), 25 ); 
				
				// Handle stock
				add_filter( 'woocommerce_stock_html', array($this, 'stock_html'), 10, 2 );
				
				add_filter( 'woocommerce_get_price', array($this, 'wpsd_get_price'), 10, 2 );
				
				// Change Add to cart button text action
				add_filter( 'single_add_to_cart_text', array($this, 'single_add_to_cart_text'), 10, 2 );
				
				// Handle variation price for on change
				add_filter( 'woocommerce_available_variation', array($this, 'wpsd_available_variation'), 10, 3 );
				
			}
		}
	}
	
	/**
	 * Adding Hooks
	 *
	 * Adding proper hooks for the public class
	 *
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	public function add_hooks() {
		
		//load the wp action to load the all action and filter if deal is enable for
		//particulare product
		add_action( 'wp', array( $this, 'wpsd_load_deals_actions' ) );
		
		//template loader
		add_filter( 'template_include', array( $this, 'wpsd_load_template' ) );
		
		//ajax call to update data to database this action will be using in add on also
		add_action( 'wp_ajax_wpsd_update_social_media_values', array( $this, 'wpsd_update_social_count' ) );
		add_action( 'wp_ajax_nopriv_wpsd_update_social_media_values', array( $this, 'wpsd_update_social_count' ) );
	
		//do action to set cookie for social discount
		add_action( 'wpsd_update_social_data', array($this, 'wpsd_set_social_discount_applied'),10,2);
		
		//stock reduce filter for dimsale increasing price
		add_action( 'woocommerce_order_status_completed', array( $this, 'wpsd_increase_sale_price' ) );
	}
}
?>