<?php 

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

/**
 * Renderer Class
 *
 * To handles some small HTML content for front end
 * 
 * @package WooCommerce WP Social Deals
 * @since 1.0.0
 */
class Wpsd_Renderer {
	
	var $model;
	
	public function __construct() {

		global $wpsd_model;
		$this->model = $wpsd_model;
		
	}
	
	/**
	 * WooCommerce custom product tab
	 * 
	 * Adds a new tab to the Product Data postbox in the admin product interface
	 *
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	public function product_write_panel_tab() {
		
		echo "<li class=\"wpsocial_deals_tab\"><a href=\"#woocommerce_wpsocial_deals\">" . __( 'Social Deals' ) . "</a></li>";
		
	}
	
	/**
	 * WooCommerce custom product tab data
	 * 
	 * Adds the panel to the Product Data postbox in the product interface
	 *
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	public function product_write_panel() {
		global $post;
		// the product
		
		$product_type = $this->model->wpsd_get_product_type( $post->ID );
		
		$prefix = '_wpsd_';
		
		$currency_symbol = get_woocommerce_currency_symbol();
		
		$enable = '';
		
		$end_date = $this->model->wpsd_get_end_date( $post->ID );
		$enable = get_post_meta( $post->ID, $prefix . 'enable', true );
		
		// display the custom tab panel
		echo '<div id="woocommerce_wpsocial_deals" class="panel wc-metaboxes-wrapper woocommerce_options_panel">';

			$error_message = '<p>' . __( 'To use this product as a Deal, please set at least the end date on the General Tab > Sale Price Dates.', 'wpsd') . '</p>';
			echo '<div id="wpsd-error-message-box" class="wpsd-error-message">' . $error_message . '</div>';
			
		woocommerce_wp_checkbox( array( 'id' => $prefix . 'enable', 'class' => 'wpsd-enable', 'cbvalue' => '1', 'label' => __( 'Activate:', 'wpsd' ), 'description' => __( 'Check this box, if you want to activate this product as a Deal.', 'wpsd' ) ) );
		woocommerce_wp_checkbox( array( 'id' => $prefix . 'expired_deals', 'class' => 'wpsd-expired-deals', 'cbvalue' => '1', 'label' => __( 'Display Expired Deals:', 'wpsd' ), 'description' => __( 'Check this box, if you want to display expired Deals. If unchecked the "normal" page design will appear again, after the Deal ended.', 'wpsd' ) ) );
			
		$startdate = get_post_meta( $post->ID, '_wpsd_start_date', true);
		$startdate = (!empty($startdate)) ? date_i18n('d-m-Y h:i a',$startdate) : '';
	
		$enddate = get_post_meta( $post->ID, '_wpsd_end_date', true);
		$enddate = (!empty($enddate)) ? date_i18n('d-m-Y h:i a',$enddate) : '';
	
		echo '<div class="wpsd-start-end-date">';	
			woocommerce_wp_text_input( array( 'id' => $prefix . 'start_date', 'class' => 'wpsd-meta-date', 'value' => $startdate, 'label' => __( 'Start Date:', 'wpsd' ), 'description' => __( 'Choose a start date for this Deal.', 'wpsd' ) ) );
			woocommerce_wp_text_input( array( 'id' => $prefix . 'end_date', 'class' => 'wpsd-meta-date', 'value' => $enddate, 'label' => __( 'End Date:', 'wpsd' ), 'description' => __( 'Choose an end date for this Deal.', 'wpsd' ) ) );
		echo '</div>';
		
		$this->woocommerce_wp_image( array( 'id' => $prefix . 'main_image', 'class' => 'wpsd-main-image', 'label' => __( 'Deal Main Image:', 'wpsd' ), 'description' => __( 'Upload the main image for the Deal. This is the image which is being used on the Deals overview page. This image should have a width of around 600px, depending on your theme and it looks best, if the image is rectangular. Please just make sure, that all the images you\'re using for the different Deals, do have the same size in width and height.', 'wpsd' ) ) );
		woocommerce_wp_select( array( 'id' => $prefix . 'home_page', 'class' => 'wpsd-home-page', 'options' => array( '0' => __( 'No', 'wpsd' ), '1' => __( 'Yes', 'wpsd' ) ), 'label' => __( 'Display on Home Page:', 'wpsd' ), 'description' => __( 'Select yes, if you want to display this Deal on the Deals home/overview page.', 'wpsd' ) ) );
		woocommerce_wp_text_input( array( 'id' => $prefix . 'inc_price', 'class' => 'wpsd-inc-price', 'label' => __( 'Increase Price ( '.$currency_symbol.' ):', 'wpsd' ), 'description' => __( 'If you want to use this Deal as a dime sale, then you can enter the price for which it should increase here.', 'wpsd' ) ) );
		woocommerce_wp_text_input( array( 'id' => $prefix . 'inc_ratio', 'class' => 'wpsd-inc-ratio', 'label' => __( 'Increase Price Ratio:', 'wpsd' ), 'description' => __( 'If you want to use this Deal as a dime sale, then you can enter the amount of sales after which the price should mincrease here.', 'wpsd' ) ) );
		woocommerce_wp_text_input( array( 'id' => $prefix . 'purchase_link', 'class' => 'wpsd-purchase-link', 'label' => __( 'Purchase Link:', 'wpsd' ), 'description' => __( 'If this is an affiliate or CPA Deal, then you can enter the URL to that Deal here. If an URL is entered, then the product won\'t be added to the cart.', 'wpsd' ) ) );
		woocommerce_wp_checkbox( array( 'id' => $prefix . 'claim_offer_link', 'class' => 'wpsd-claim-offer-link', 'cbvalue' => '1', 'label' => __( 'Claim Offer Link:', 'wpsd' ), 'description' => __( 'If you want users to subscribe to your list to be able to claim this Deal, then check this box.', 'wpsd' ) ) );
		woocommerce_wp_text_input( array( 'id' => $prefix . 'claim_offer_title', 'class' => 'wpsd-claim-offer-title', 'label' => __( 'Claim Offer Title: ', 'wpsd' ), 'description' => __( 'Here you can enter the title for the claim offer content.', 'wpsd' ) ) );
		$this->woocommerce_wp_editor_textarea( array( 'id' => $prefix . 'claim_offer_content', 'class' => 'wpsd-claim-offer-content', 'label' => __( 'Claim Offer Content: ', 'wpsd' ), 'description' => __( 'Here you can enter your content to explain how they can claim this Deal. You can also add your optin form code here. To do so, click on the Text tab above the editor and copy and paste your optin code.', 'wpsd' ) ) );
		woocommerce_wp_text_input( array( 'id' => $prefix . 'add_to_cart', 'class' => 'wpsd-add-to-cart', 'label' => __( 'Add To Cart Text:', 'wpsd' ), 'description' => __( 'Here you can enter a custom "Add To Cart" text, which will be displayed on the button. Leave it empty to use the standard one.', 'wpsd' ) ) );
		woocommerce_wp_checkbox( array( 'id' => $prefix . 'available_bought', 'class' => 'wpsd-available-bought', 'cbvalue' => '1', 'label' => __( 'Available & Bought Box:', 'wpsd' ), 'description' => __( 'Check this box, if you don\'t want to show the available and bought box for this Deal.', 'wpsd' ) ) );
		woocommerce_wp_text_input( array( 'id' => $prefix . 'business_title', 'class' => 'wpsd-business-title', 'label' => __( 'Business Title:', 'wpsd' ), 'description' => __( 'Enter a title about the business. This will appear above the business information related to this Deal. Leave it blank if you don\'t want to use it.', 'wpsd' ) ) );
		$this->woocommerce_wp_image( array( 'id' => $prefix . 'business_logo', 'class' => 'wpsd-business-logo', 'label' => __( 'Business Logo:', 'wpsd' ), 'description' => __( 'Upload the business logo related to this Deal. Leave it blank if you don\'t want to use it.', 'wpsd' ) ) );
		woocommerce_wp_textarea_input( array( 'id' => $prefix . 'business_address', 'class' => 'wpsd-business-address', 'label' => __( 'Business Address:', 'wpsd' ), 'description' => __( 'Enter the address of the business related to this Deal. Leave it blank if you don\'t want to use it.', 'wpsd' ) ) );
		woocommerce_wp_text_input( array( 'id' => $prefix . 'business_web_url', 'class' => 'wpsd-business-web-url', 'label' => __( 'Business Website URL:', 'wpsd' ), 'description' => __( 'Enter the URL of the business which provides this Deal. The URL must start with http://', 'wpsd' ) ) );
		woocommerce_wp_text_input( array( 'id' => $prefix . 'map_address', 'class' => 'wpsd-map-address', 'label' => __( 'Map Address:', 'wpsd' ), 'description' => __( 'Enter the complete address which will be used for the Google Map. Leave it blank if you don\'t want to show a Google Map.', 'wpsd' ) ) );
		woocommerce_wp_text_input( array( 'id' => $prefix . 'map_popup_width', 'class' => 'wpsd-map-popup-width', 'label' => __( 'Map Popup Width:', 'wpsd' ), 'description' => __( 'Enter a max width for the Google Map popup window. Please enter only a numeric value (eg.50).', 'wpsd' ) ) );
		$this->woocommerce_wp_editor_textarea( array( 'id' => $prefix . 'popup_content', 'class' => 'wpsd-popup-content', 'label' => __( 'Popup Content:', 'wpsd' ), 'description' => __( 'Here you can enter custom content for the Google Map popup window. If you leave that empty, the address will be displayed.', 'wpsd' ) ) );
		woocommerce_wp_textarea_input( array( 'id' => $prefix . 'term_cond', 'class' => 'wpsd-term-cond', 'label' => __( 'Terms & Conditions:', 'wpsd' ), 'description' => __( 'Enter the Terms & Conditions for this Deal here.', 'wpsd' ) ) );
		woocommerce_wp_text_input( array( 'id' => $prefix . 'sharing_discount_link_title', 'class' => 'wpsd-sharing-discount-link-title', 'label' => __( 'Sharing Discount Link Title:', 'wpsd' ), 'description' => __( 'Enter a title for the social sharing discount here. This will be displayed above the social sharig buttons. If you then enter any content below, this title will become a link and if the user clicks on it, a pop up will display the content.', 'wpsd' ) ) );
		woocommerce_wp_text_input( array( 'id' => $prefix . 'sharing_discount_title', 'class' => 'wpsd-sharing-discount-title', 'label' => __( 'Sharing Discount Title:', 'wpsd' ), 'description' => __( 'Enter a title for the social sharing discount content here. This title will be used within the pop up window.', 'wpsd' ) ) );
		$this->woocommerce_wp_editor_textarea( array( 'id' => $prefix . 'sharing_discount_content', 'class' => 'wpsd-sharing-discount-content', 'label' => __( 'Sharing Discount Content:', 'wpsd' ), 'description' => __( 'Here you can enter your content to explain the social sharing discounts to your users.', 'wpsd' ) ) );
		woocommerce_wp_text_input( array( 'id' => $prefix . 'fb_discount', 'class' => 'wpsd-fb-discount', 'label' => __( 'Facebook Sharing Discount:', 'wpsd' ), 'description' => __( 'Enter the discount amount you want to give when an user shares this Deal on Facebook. Enter numbers only. For example 0.50.', 'wpsd' ) ) );
		woocommerce_wp_text_input( array( 'id' => $prefix . 'fan_page_discount', 'class' => 'wpsd-fan-page-discount', 'label' => __( 'Facebook Fan Page Like Discount:', 'wpsd' ), 'description' => __( 'Enter the discount amount you want to give when users become a Fan of your Facebook Fan Page. Enter numbers only. For example 0.50.', 'wpsd' ) ) );
		woocommerce_wp_text_input( array( 'id' => $prefix . 'fan_page_link', 'class' => 'wpsd-fan-page-link', 'label' => __( 'Facebook Fan Page Link:', 'wpsd' ), 'description' => __( 'Enter the URL to your Facebook Fan Page. The URL must start with http://.', 'wpsd' ) ) );
		woocommerce_wp_text_input( array( 'id' => $prefix . 'tw_discount', 'class' => 'wpsd-tw-discount', 'label' => __( 'Twitter Sharing Discount:', 'wpsd' ), 'description' => __( 'Enter the discount amount you want to give when an user shares this Deals on Twitter. Enter numbers only. For example 0.50.', 'wpsd' ) ) );
		woocommerce_wp_text_input( array( 'id' => $prefix . 'gp_discount', 'class' => 'wpsd-gp-discount', 'label' => __( 'Google+ Sharing Discount:', 'wpsd' ), 'description' => __( 'Enter the discount amount you want to give when an user shares this Deals on Google+. Enter numbers only. For example 0.50.', 'wpsd' ) ) );

		echo '</div>'; 
	}
	 
	/**
	 * Show Image Uploader in metabox
	 * 
	 * Handles to image uploader as per
	 * version of wordpress
	 *
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	
	public function woocommerce_wp_image( $field ) {
		
		global $thepostid, $post, $wp_version;

		if ( ! $thepostid ) $thepostid = $post->ID;
		if ( ! isset( $field['placeholder'] ) ) $field['placeholder'] = '';
		if ( ! isset( $field['class'] ) ) $field['class'] = 'short';
		if ( ! isset( $meta ) ) $meta = get_post_meta( $thepostid, $field['id'], true );

		echo '<p class="form-field ' . $field['id'] . '_field"><label style="display:block;" for="' . $field['id'] . '">' . $field['label'] . '</label>';
	
		$html = wp_nonce_field( "wpsd-meta-delete-mupload_{$field['id']}", "nonce-delete-mupload_".$field['id'], false, false );
	
		if( is_array( $meta ) ) {
			if( isset( $meta[0] ) && is_array( $meta[0] ) ) {
				$meta = $meta[0];
			}
		}
		 
		if( is_array( $meta ) && isset( $meta['src'] ) && $meta['src'] != '' ) {
			$html .= "<span class='mupload_img_holder'><img src='".$meta['src']."' style='width: 150px;' /></span>";
			$html .= "<input type='hidden' name='".$field['id']."[id]' id='".$field['id']."[id]' value='".$meta['id']."' />";
			$html .= "<input type='hidden' name='".$field['id']."[src]' id='".$field['id']."[src]' value='".$meta['src']."' />";
			$html .= "<input class='wpsd-meta-delete_image_button button' type='button' rel='".$field['id']."' value='" . __( 'Delete Image', 'wpsd' ) . "' />";
		} else {
			$html .= "<span class='mupload_img_holder'></span>";
			$html .= "<input type='hidden' name='".$field['id']."[id]' id='".$field['id']."[id]' value='' />";
			$html .= "<input type='hidden' name='".$field['id']."[src]' id='".$field['id']."[src]' value='' />";
			$html .= "<input class='wpsd-meta-upload_image_button button' type='button' rel='".$field['id']."' value='" . __( 'Upload Image', 'wpsd' ) . "' />";
		}
		
		echo $html;
		
		if ( isset( $field['description'] ) && $field['description'] )
			echo '<span class="description">' . $field['description'] . '</span>';

		echo '</p>';
		
	}

	/**
	 * Show WP Editor in metabox
	 * 
	 * Handles to show editor / textarea as per
	 * version of wordpress
	 *
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	
	public function woocommerce_wp_editor_textarea( $field ) {
		
		global $thepostid, $post, $wp_version;

		if ( ! $thepostid ) $thepostid = $post->ID;
		if ( ! isset( $field['placeholder'] ) ) $field['placeholder'] = '';
		if ( ! isset( $field['class'] ) ) $field['class'] = 'short';
		if ( ! isset( $field['value'] ) ) $field['value'] = get_post_meta( $thepostid, $field['id'], true );

		// Add TinyMCE script for WP version < 3.3
		if ( version_compare( $wp_version, '3.2.1' ) < 1 ) {
			
			echo '<p class="form-field ' . $field['id'] . '_field"><label style="display:block;" for="' . $field['id'] . '">' . $field['label'] . '</label>';
		
			echo '<textarea class="' . $field['class'] . '" name="' . $field['id'] . '" id="' . $field['id'] . '" placeholder="' . $field['placeholder'] . '" rows="2" cols="20"' . (isset( $field['style'] ) ? ' style="' . $field['style'] . '"' : '') . '>' . esc_textarea( $field['value'] ) . '</textarea> ';
			
			if ( isset( $field['description'] ) && $field['description'] )
				echo '<span class="description">' . $field['description'] . '</span>';

			echo '</p>';
			
		} else {
			
			echo '<label class="wps-editor-label" style="display:block;" for="' . $field['id'] . '">' . $field['label'] . '</label>';
			echo '<div class="wpsd-editor-meta">';
			wp_editor( html_entity_decode($field['value']), $field['id'], array( 'editor_class' => 'wpsd-meta-editor' ) );
			echo '</div>';
			if ( isset( $field['description'] ) && $field['description'] )
				echo '<span class="description wps-editor-description">' . $field['description'] . '</span>';

		}
	}

	/**
	 * Google Maps
	 *
	 * This creates the markup for the google maps.
	 *
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	public function wpsd_google_maps_markup() {
	
		$gmapaddress = get_post_meta( get_the_ID(), '_wpsd_map_address', true );
		$address = str_replace("'", "&prime;", $gmapaddress);
		
		wp_enqueue_script('wpsd-google-map');
		wp_enqueue_script('wpsd-map-script');
		
		$googlemaps = '<div class="wpsd-map" id="map"></div>';
	   
		return $googlemaps;
	}
		
}
?>