<?php

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

/**
 * Scripts Class
 *
 * Handles adding scripts functionality to the admin pages
 * as well as the front pages.
 *
 * @package WooCommerce WP Social Deals
 * @since 1.0.0
 */
class Wpsd_Scripts {

	public function __construct() {
		
	}
	
	/**
	 * Main entry point.
	 *
	 * @static
	 */
	public static function serve() {
		
		$me = new Wpsd_Scripts();
		$me -> add_hooks();
	}
	
	/**
	 * Enqueue Script for Metabox Tab
	 * 
	 * Loads Script to handle Metabox Tab functionlities
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	public function wpsd_back_end_scripts() {
		
		global $wp_version;
		
		wp_enqueue_script(array('jquery','jquery-ui-core', 'jquery-ui-sortable', 'jquery-ui-datepicker','jquery-ui-slider'));
		
		wp_deregister_script( 'datepicker-slider' );
		wp_register_script('datepicker-slider', WPSD_URL . 'includes/js/datetimepicker/jquery-ui-slider-Access.js');
		wp_enqueue_script('datepicker-slider');
		
		wp_deregister_script( 'timepicker-addon' );
		wp_register_script('timepicker-addon', WPSD_URL . 'includes/js/datetimepicker/jquery-date-timepicker-addon.js',array('datepicker-slider'),false,true);
		wp_enqueue_script('timepicker-addon');
		
		wp_register_script( 'wpsd-admin-scripts', WPSD_URL . 'includes/js/wpsd-admin.js', array('jquery'), null, true );
		wp_enqueue_script( 'wpsd-admin-scripts' );
		
		//localize script
		$newui = $wp_version >= '3.5' ? '1' : '0'; //check wp version for showing media uploader
		wp_localize_script( 'wpsd-admin-scripts','Wpsd',array(	
																'new_media_ui'	=>	$newui
															) );
		wp_enqueue_script( 'media-upload' );
		add_thickbox();
	}
	
	/**
	 * Enqueue Style for WPSocial Deals Meta Tab
	 * 
	 * Loads Style to handle WPSocial Deals Meta Tab functionlities
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	public function wpsd_back_end_styles() {
		
		wp_register_style( 'wpsd-date-timepicker-styles', WPSD_URL . 'includes/css/datetimepicker/date-time-picker.css' );
		wp_enqueue_style( 'wpsd-date-timepicker-styles' ); 
		
		wp_register_style( 'wpsd-styles', WPSD_URL . 'includes/css/wpsd-admin.css' );
		wp_enqueue_style( 'wpsd-styles' ); 
	}
	
	/**
	 * Enqueue Style for WPSocial Deals Meta Tab
	 * 
	 * Loads Style to handle WPSocial Deals Meta Tab functionlities
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	public function wpsd_front_styles() {
		
		$disable_bootstrap = get_option('disable_twitter_bootstrap');
		
		wp_register_style( 'wpsd-bootstrap-styles', WPSD_URL . 'includes/css/bootstrap.css' );
		if( empty($disable_bootstrap) || $disable_bootstrap == 'no' ) {
			wp_enqueue_style( 'wpsd-bootstrap-styles' );
		}
		wp_register_style( 'wpsd-public-styles', WPSD_URL . 'includes/css/wpsd-public.css' );
		wp_enqueue_style( 'wpsd-public-styles' ); 
	}
	
	/**
	 * Enqueue Scripts for frontside
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	public function wpsd_front_scripts() {
		
		global $post;
		
		if(is_singular()) {
			
			$deals_caching = get_option('deals_caching');
			$twitter_user = get_option('tw_user_name');
			$facebook_button = get_option('social_buttons_facebook');
			$twitter_button = get_option('social_buttons_twitter');
			$google_button = get_option('social_buttons_google');
			$fanpage_button = get_option('social_buttons_fanpage');
			
			// get the value for the google map address from the post meta box
			$gmapaddress = get_post_meta( $post->ID, '_wpsd_map_address', true );
			$gmapaddress = isset($gmapaddress) && !empty($gmapaddress) ? $gmapaddress : '';
			
			// get the value for the google map popup content from the post meta box
			$gmappopupcontent = get_post_meta( $post->ID, '_wpsd_popup_content', true );
			$gmappopupcontent = isset($gmappopupcontent) && !empty($gmappopupcontent) ? $gmappopupcontent : '';
			
			// get the value for the google map popup max width from the post meta box
			$gmapwidth = get_post_meta( $post->ID, '_wpsd_map_popup_width', true );
			
			$popupmaxwidth = isset($gmapwidth) && !empty($gmapwidth) ? $gmapwidth : '220';
			
			$address = str_replace("'", "&prime;", $gmapaddress);
			
			if (!empty($gmappopupcontent)) { //check google map popup content
				$popupcontent =  '<div class="wpsd-gmap-popup-content">'.$gmappopupcontent.'</div>';
			} else {
				$popupcontent = $address;
			}	
			
			//get caching is on site or not
			$caching = isset( $deals_caching ) && $deals_caching == 'yes' ? '1' : '';
			
			wp_register_script( 'wpsd-public-script', WPSD_URL . 'includes/js/wpsd-public.js', array('jquery'), null );	
			wp_enqueue_script( 'wpsd-public-script' ); 
			
			wp_localize_script( 'wpsd-public-script', 'Wpsd_Public', array( 
																				'ajaxurl' 	=>	admin_url('admin-ajax.php'),
																				'caching'	=>	$caching
																			) );
			
			wp_register_script( 'wpsd-bootstrap-script', WPSD_URL . 'includes/js/bootstrap.js', array(), null, true );	
			
			// register google Map Js files 
			wp_register_script( 'wpsd-google-map', "http://maps.google.com/maps/api/js?sensor=false", array(), null, true );
			wp_register_script( 'wpsd-map-script', WPSD_URL . 'includes/js/wpsd-map.js', array(), null, true );	
			wp_localize_script( 'wpsd-map-script', 'Wpsd_Map', array( 
																		'URL' 			=>	WPSD_IMG_URL,
																	   	'address'		=>	$address,
																	   	'popupcontent' 	=> 	$popupcontent,
																	  	'popupmaxwidth'	=>	$popupmaxwidth
																	) );
			//facebook button or fanpage button is enable or not
			if( isset($facebook_button) && $facebook_button == 'yes' || isset($fanpage_button) && $fanpage_button == 'yes' ) {
				wp_deregister_script('facebook');
				wp_register_script( 'facebook', 'http://connect.facebook.net/en_US/all.js#xfbml=1',array( 'jquery' ), null );
				wp_enqueue_script( 'facebook' );
			}
			
			//twitter button is enable or not
			if( isset($twitter_button) && $twitter_button == 'yes' && !empty($twitter_user) ) {
				wp_deregister_script('twitter');
				wp_register_script( 'twitter', 'http://platform.twitter.com/widgets.js',array( 'jquery' ), null );
				wp_enqueue_script( 'twitter' );
			}
			
			//google plus button is enable or not
			if( isset($google_button) && $google_button == 'yes' ) {
				wp_deregister_script('google');
				wp_register_script( 'google', 'https://apis.google.com/js/plusone.js',array( 'jquery' ), null );
				wp_enqueue_script( 'google' );
			}
		}
	}
	
	/**
	 * Adding Hooks
	 *
	 * Adding proper hooks for the scripts.
	 *
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0 
	 */
	public function add_hooks() {
		
		//styles for backend
		add_action( 'admin_print_styles', array( $this, 'wpsd_back_end_styles'));
		
		//scripts for backend
		add_action( 'admin_print_scripts', array( $this, 'wpsd_back_end_scripts'));
		 
		//style for front side
		add_action( 'wp_print_styles', array( $this, 'wpsd_front_styles'));
		
		//script for front side
		add_action( 'wp_enqueue_scripts', array( $this, 'wpsd_front_scripts')); 
		
	}
}
?>