<?php 

/**
 * Template Add to Cart
 * 
 * Handles to show add to cart on single 
 * deal view page
 * 
 * @package WooCommerce WP Social Deals
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

	global $post,$wpsd_model,$wpsd_price,$product;
	
	$size = get_option('deals_size');
	
	//model class
	$model = $wpsd_model;
	
	//price class
	$price = $wpsd_price;
	
	$normalprice = $price->wpsd_get_normal_price();
	
	$saleprice = $product->get_price();
	
	//product price 
	$productprice = $price->wpsd_get_price($normalprice, $saleprice);
	$displayprice = $price->wpsd_get_display_price( $productprice );
	
	//current date time
	$today = date('Y-m-d H:i:s');
	
	//get the value for start date & time of deals from the post meta box
	$startdate = $model->wpsd_get_start_date( $post->ID );
	
	//get the value for end date & time of deals from the post meta box
	$enddate = $model->wpsd_get_end_date( $post->ID );
	
	//get the purchase link for affiliate products 
	$purchaselink = get_post_meta($post->ID,'_wpsd_purchase_link',true);
	
	// get the claim offer link value
	$claim_offer_link = get_post_meta($post->ID,'_wpsd_claim_offer_link',true);
	
	// get the claim offer title value
	$claim_offer_title = get_post_meta($post->ID,'_wpsd_claim_offer_title',true);
	
	// get the claim offer content value
	$claim_offer_content = get_post_meta($post->ID,'_wpsd_claim_offer_content',true);

	//get add to cart button 
	$addtocart_post = get_post_meta($post->ID,'_wpsd_add_to_cart',true);
	if( !empty( $addtocart_post ) ) { //check add to cart button text set in metabox or not
		$addcartbtntext = $addtocart_post;
	} else {
		$addcartbtntext = __('Add to Cart', 'wpsd');
	}
	 
?>
	<div class="wpsd-product-btn row-fluid <?php _e($size); ?>">

	<?php
		//check purchase link in metabox is set or not
		if( !empty( $purchaselink ) ) {
			
			//remove woocommerce add to cart button and put deals cart button
			remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart', 30 ); 
			wpsd_get_template( 'single-deal/add-to-cart/purchase-link-cart-button.php', array( 'addcartbtntext' => $addcartbtntext, 'displayprice' => $displayprice, 'purchaselink' => $purchaselink ) );
	
		} elseif( $claim_offer_link == '1' ) {  //check claim offer link is set or not
			
			//remove woocommerce add to cart button and put deals cart button
			remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart', 30 ); 
			wpsd_get_template( 'single-deal/add-to-cart/claim-cart-button.php', array( 'addcartbtntext' => $addcartbtntext, 'claimtitle' => $claim_offer_title, 'claimcontent' => $claim_offer_content ) );
			
		} else if( !empty($startdate) && !empty($enddate) && $startdate <= $today && $enddate <= $today ) { //check deal is expired or not
		
			//remove woocommerce add to cart button and put deals cart button
			remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart', 30 ); 
			wpsd_get_template( 'single-deal/deal-expired.php' );
		}
	?>

	</div><!--wpsd-product-btn-->