<?php

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

add_action( 'widgets_init', 'wpsd_lists_widget' );

/**
 * Register the Deals Listing
 * 
 * Handles to register a widget
 * for showing active deals
 *
 * @package WooCommerce WP Social Deals
 * @since 1.0.
 */
function wpsd_lists_widget() {
	register_widget( 'Wpsd_Lists' );
}

/**
 * Woocommerce WP Social Deals Widget Class. 
 *
 * This class handles everything that needs to be handled with the widget:
 * the settings, form, display, and update for displaying submitted reviews.
 *
 * @package WooCommerce WP Social Deals
 * @since 1.0.
 */ 
class Wpsd_Lists extends WP_Widget {

	var $model,$render,$price;

	/**
	 * Widget setup.
	 */
	function Wpsd_Lists() {
	
		global $wpsd_model,$wpsd_render,$wpsd_price;
		
		$this->model = $wpsd_model;
		$this->render = $wpsd_render;
		$this->price = $wpsd_price;
		
		/* Widget settings. */
		$widget_ops = array( 'classname' => 'wpsd-lists', 'description' => __( 'A Social Deals widget, which lets you display your active Deals.', 'wpsd' ) );

		/* Create the widget. */
		$this->WP_Widget( 'wpsd-lists', __( 'WooCommerce Social Deals', 'wpsd' ), $widget_ops );
	
	}
	
	/**
	 * Outputs the content of the widget
	 * 
	 * Handles to show output of widget 
	 * at front side sidebar
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 * 
	 */
	function widget( $args, $instance ) {
	
		global $wpdb,$post,$wpsd_price,$wpsd_model;
		
		extract( $args );
		
		//model class
		$model = $wpsd_model;
		
		//get the options value from settings page
		$wpsd_pages = get_option('deals_main_page');
		 
		//get the value for deals listing page
		$dealspage = $wpsd_pages;
		
		//current date and time
		$today = date_i18n('Y-m-d H:i:s');
		$today = strtotime( $today );
		
		$title = apply_filters( 'widget_title', $instance['title'] );
		$limit = $instance['limit'];
		$disable_price 	= $instance['disable_price'];
		$disable_timer 	= $instance['disable_timer'];
		
		/* all active deals listing start */ 
		$dealsmetaquery = array( 
								
								array(		
											'key' => '_sale_price_dates_from',
											'value' => $today,
											'compare' => '<=',
											'type' => 'STRING'
									),
								array(
											'key' => '_sale_price_dates_to',
											'value' => $today,
											'compare' => '>=',
											'type' => 'STRING'
									),
								array(
											'key' => '_wpsd_enable',
											'value' => '1',
											'compare' => '=',
											'type' => 'STRING'
									)
							 );
		$this_post = $post->ID;
		$argswidget = array( 'post_type' => WPSD_POST_TYPE, 'posts_per_page' => $limit, 'post__not_in' => array( $this_post ), 'meta_query' => $dealsmetaquery );
		
		$loop = null;
		$loop = new WP_Query();
		$loop->query( $argswidget );
		
		$html = '';
		
		if( $loop->have_posts() ) {
        	
        	echo $before_widget;
        
        	$html .= '<div class="wpsd-widget-content">';
        	
    	   	if ( $title )
				
				$alldeals = '<div class="wpsd-widget-after-title"><a href="'.get_permalink($dealspage).'">'.__('See All','wpsd').'</a></div>';
				
	            echo $before_title . $title . $alldeals . $after_title;
        	
        	while ( $loop->have_posts() ) : $loop->the_post();
		
				if($post->post_status == 'publish') { //check post type is published
					
					global $product;
					
					// get the value of image url from featured image
	        		$imgurl = wp_get_attachment_url( get_post_thumbnail_id( $post->ID ) );
	        	
					// get the value for deal price from the post meta box
					$normalprice = $wpsd_price->wpsd_get_normal_price();
					
					// get the value for deal sale price from the post meta box
					$saleprice = $product->get_price();
					
					//get the value for start date & time of deals from the post meta box
					$startdate = $model->wpsd_get_start_date( $post->ID );
					
					//get the value for end date & time of deals from the post meta box
					$enddate = $model->wpsd_get_end_date( $post->ID );
					
					//calculate saving price
					$yousave = $this->price->wpsd_get_savingprice($normalprice,$saleprice);
					
					//get product price
					$price = $this->price->wpsd_get_price($normalprice,$saleprice);
					
					//product price 
					$productprice = $this->price->wpsd_get_display_price($price);
					
					//discount 
					$discount = $this->price->wpsd_get_discount($normalprice,$saleprice);
					
			        $html .= '<div class="wpsd-widget-parent">';
			        
			        $html .= ' 		<div class="wpsd-sub-content">';
					
			        $imgurl = !empty($imgurl) && !empty($imgurl) ? $imgurl : WPSD_IMG_URL.'/deals-no-image-big.jpg';
										
			        
					$html .= '			<div class="wpsd-img-flag-small widget-flag">'.$productprice.'</div>
										<div align="center" class="wpsd-widget-img">
											<a href="'.get_permalink($post->ID).'" title="'.get_the_title($post->ID).'"><img src="'.$imgurl.'" alt="'.__('Deal Image','wpsd').'" /></a>
										</div>';
					
					if( empty($disable_price) ) {
						
						$html .= '		<div class="wpsd-widget-price-box">
											<div class="wpsd-widget-price">
												<span>'.__('Deal Value','wpsd').'</span>
												<div>'.$this->price->wpsd_get_display_price($normalprice).'</div>
											</div>';
												
						$html .= '			<div class="wpsd-widget-price-middle">
												<span>'.__('Discount','wpsd').'</span>
												<div>'.$discount.'</div>
											</div>';
												
						$html .= '			<div class="wpsd-widget-price-last">
												<span>'.__('You Save','wpsd').'</span>
												<div>'.$yousave.'</div>
											</div>
										</div>';
					}
					$html .= '		</div><!--.wpsd-sub-content-->';
					
					$today = date_i18n('Y-m-d H:i:s');

					$difference = strtotime($enddate) - strtotime($today);
					
					$datediff = $this->model->wpsd_seconds_to_time($difference);
					
					$html .= '		<div class="wpsd-contentdeal-footer footer-widget">';
					
					if( empty($disable_timer) ) {
					
						$html .= '		<div class="wpsd-timing"><span class="timer-icon-small"></span><span class="wpsd-widget-ending">'.$datediff.'</span></div>';
					
					}
					$html .= '			<div class="wpsd-btn-small"><a href="'.get_permalink($post->ID).'">'.__('See Deal','wpsd').'</a></div>
									</div>';
					
				 	$html .= '</div><!--.wpsd-parent-->';
				}
				
			endwhile;
			
			//end container
        	$html .= '</div><!--.wpsd-widget-content-->';
        
			echo $html;
			echo $after_widget;
        }
	
		wp_reset_query();  
    }
	
	/**
	 * Updates the widget control options for the particular instance of the widget
	 *
	 * Handles to update widget data
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0 
	 *
	 */
	function update( $new_instance, $old_instance ) {
	
        $instance = $old_instance;
		
		/* Set the instance to the new instance. */
		$instance = $new_instance;
		
		/* Input fields */
        $instance['title'] = strip_tags( $new_instance['title'] ); 
		$instance['limit'] = strip_tags( $new_instance['limit'] );
		$instance['disable_price'] 	= strip_tags( $new_instance['disable_price'] );
		$instance['disable_timer'] 	= strip_tags( $new_instance['disable_timer'] );
		
        return $instance;
		
    }
	
	/**
	 * Displays the widget form in the admin panel
	 * 
	 * Handles to show widget settings at backend
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 * 
	 */
	function form( $instance ) {
	
		$defaults = array( 'title' => __('More Great Deals', 'wpsd'), 'limit' => '3', 'disable_price' => '', 'disable_timer' => '');
		
        $instance = wp_parse_args( (array) $instance, $defaults );
		
		?>
		
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'wpsd'); ?></label> 
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $instance['title']; ?>" />
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( 'limit' ); ?>"><?php _e( 'Limit:', 'wpsd'); ?></label> 
			<input class="widefat" id="<?php echo $this->get_field_id( 'limit' ); ?>" name="<?php echo $this->get_field_name( 'limit' ); ?>" type="text" value="<?php echo $instance['limit']; ?>" />
		</p>
		<p>
			<input id="<?php echo $this->get_field_id( 'disable_price' ); ?>" type="checkbox" name="<?php echo $this->get_field_name( 'disable_price' ); ?>" value="1" <?php checked( $instance['disable_price'],'1', true ); ?> />
			<label for="<?php echo $this->get_field_id( 'disable_price' ); ?>"><?php _e( 'Disable Price Box', 'wpsd'); ?></label>
		</p>
		<p>
			<input id="<?php echo $this->get_field_id( 'disable_timer' ); ?>" type="checkbox" name="<?php echo $this->get_field_name( 'disable_timer' ); ?>" value="1" <?php checked( $instance['disable_timer'], '1', true ); ?> />
			<label for="<?php echo $this->get_field_id( 'disable_timer' ); ?>"><?php _e( 'Disable Timer', 'wpsd'); ?></label>
		</p>

		<?php
	}
}