<?php

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

/**
 * Templates Functions
 *
 * Handles to manage templates of plugin
 * 
 * @package WooCommerce WP Social Deals
 * @since 1.0.0
 *
 */ 


/**
 * Returns the path to the Deals templates directory
 *
 * @package WooCommerce WP Social Deals
 * @since 1.0.0
 */
function wpsd_get_templates_dir() {
	
	return WPSD_DIR . '/includes/templates/'; 
	
}

function wpsd_get_template_part( $slug, $name='' ) {
	
	$template = '';

	// Look in yourtheme/slug-name.php and yourtheme/wpsocial-deals-engine/slug-name.php
	if ( $name )
		$template = locate_template( array ( $slug.'-'.$name.'.php', wpsd_get_templates_dir().$slug.'-'.$name.'.php' ) );

	// Get default slug-name.php
	if ( !$template && $name && file_exists( wpsd_get_templates_dir().$slug.'-'.$name.'.php' ) )
		$template = wpsd_get_templates_dir().$slug.'-'.$name.'.php';

	// If template file doesn't exist, look in yourtheme/slug.php and yourtheme/wpsocial-deals-engine/slug.php
	if ( !$template )
		$template = locate_template( array ( $slug.'.php', wpsd_get_templates_dir().$slug.'.php' ) );

	if ( $template )
		load_template( $template, false );
}


/**
 * Locate a template and return the path for inclusion.
 *
 * This is the load order:
 *
 *		yourtheme		/	$template_path	/	$template_name
 *		yourtheme		/	$template_name
 *		$default_path	/	$template_name
 * 
 * @package WooCommerce WP Social Deals
 * @since 1.0.0
 * 
 */
function wpsd_locate_template( $template_name, $template_path = '', $default_path = '' ) {
	
	if ( ! $template_path ) $template_path = WPSD_PLUGIN_BASENAME . '/';//wpsd_get_templates_dir();
	if ( ! $default_path ) $default_path = wpsd_get_templates_dir();

	// Look within passed path within the theme - this is priority
	$template = locate_template(
		array(
			trailingslashit( $template_path ) . $template_name,
			$template_name
		)
	);

	// Get default template
	if ( ! $template )
		$template = $default_path . $template_name;

	// Return what we found
	return apply_filters('wpsd_locate_template', $template, $template_name, $template_path);
}

/**
 * Get other templates (e.g. deals attributes) passing attributes and including the file.
 *
 * @package WooCommerce WP Social Deals
 * @since 1.0.0
 * 
 */

function wpsd_get_template( $template_name, $args = array(), $template_path = '', $default_path = '' ) {
	
	if ( $args && is_array($args) )
		extract( $args );

	$located = wpsd_locate_template( $template_name, $template_path, $default_path );

	do_action( 'wpsd_before_template_part', $template_name, $template_path, $located, $args );

	include( $located );

	do_action( 'wpsd_after_template_part', $template_name, $template_path, $located, $args );
}

/************************************ Call Different Templates Functions ***************************/

if( !function_exists( 'wpsd_home_header' ) ) {
	
	/**
	 * Load Home Header Template
	 * 
	 * Handles to load home page header template
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */	
	function wpsd_home_header() {
		
		$today = date_i18n('Y-m-d H:i:s');
		$today = strtotime( $today );
		
		$home_meta_args = array( 
								array(
											'key' => '_wpsd_enable',
											'value' => '1',
											'compare' => '=',
											'type' => 'STRING'
										),
								array ( 	
											'key' => '_wpsd_home_page',
											'value' => '1',
											'compare' => '=',
											'type' => 'STRING'
										),
								array (
											'key' => '_sale_price_dates_from',
											'value' => $today,
											'compare' => '<=',
											'type' => 'STRING'
										),
								array (
											'key' => '_sale_price_dates_to',
											'value' => $today,
											'compare' => '>=',
											'type' => 'STRING'
										),
					 		);
		$home_deal = array( 
								'post_type' 		=> WPSD_POST_TYPE, 
								'post_status' 		=> 'publish' , 
								'posts_per_page'	=> 1, 
								'meta_query' 		=> $home_meta_args,
								'order'				=> 'DESC',
								'orderby'			=> 'rand'
							);
							
		$loop_home = null;
		$loop_home = new WP_Query();
		$loop_home->query( $home_deal );
		
		//home page header template 
		wpsd_get_template( 'home/home-header.php', array( 'loop' => $loop_home ));
		
	}
	
}

if( !function_exists( 'wpsd_home_content' ) ) {

	/**
	 * Load Home Content Template
	 * 
	 * Handles to load home page content template
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	function wpsd_home_content() {
		
		$disable_more_deals = get_option('disable_more_deals');
		
		//check disable more deals is set or not
		if( $disable_more_deals == 'no' ) {
		
			//home page content template
			wpsd_get_template( 'home/home-content.php' );
		
		} 
	}
}

if( !function_exists( 'wpsd_home_navigations' ) ) {
	/**
	 * Load Home Page More Deals Navigation Template
	 * 
	 * Handles to load home page more deals
	 * navigation bar
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */	
	function wpsd_home_navigations() {
		//home page navigation template
		wpsd_get_template( 'home/home-content/home-navigation.php' );
	}
}

if( !function_exists( 'wpsd_home_more_deal_active' ) ) {
	/**
	 * Load Home Content Active Deals Template
	 * 
	 * Handles to home page active 
	 * deals template 
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */	
	function wpsd_home_more_deal_active( $category ) {
		
		$today = date_i18n('Y-m-d H:i:s');
		$today = strtotime( $today );
			
		$deals_per_page = get_option('deals_per_page');
		
		//get page limit from plugin settings page
		$pagelimit = isset($deals_per_page) ? $deals_per_page : -1;
		
		$homeargs = array(  
							'post_type' 	=> WPSD_POST_TYPE, 
							'post_status'	=> 'publish' , 
							'posts_per_page' => $pagelimit 
						);
		
		$activemetaquery = array( 
										array(
											'key' => '_wpsd_enable',
											'value' => '1',
											'compare' => '=',
											'type' => 'STRING'
										),
										array (
													'key' => '_sale_price_dates_from',
													'value' => $today,
													'compare' => '<=',
													'type' => 'STRING'
												),
										array (
													'key' => '_sale_price_dates_to',
													'value' => $today,
													'compare' => '>=',
													'type' => 'STRING'
												)
										
									);
									
		$activeargs = array_merge( $homeargs, array( 'meta_query' => $activemetaquery ) );
	
		if( isset( $category ) && !empty( $category ) ) { //check category id is set or not
			$activeargs[WPSD_POST_TAXONOMY] = $category;
		}
		//active deals template
		wpsd_get_template( 'home/home-content/more-deals.php', array( 'args' => $activeargs, 'tab' => 'active' ) );
	}
}

if( !function_exists( 'wpsd_home_more_deal_ending' ) ) {

	/**
	 * Load Home Content Ending Deals Template
	 * 
	 * Handles to home page ending 
	 * deals template 
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */	
	function wpsd_home_more_deal_ending( $category ) {
		
		$today = date_i18n('Y-m-d H:i:s');
		$today = strtotime( $today );
		
		$deals_per_page = get_option('deals_per_page');
		$ending_deals_in = get_option('ending_deals_in');
		
		//get page limit from plugin settings page
		$pagelimit = isset($deals_per_page) ? $deals_per_page : -1;
		
		$homeargs = array(  
							'post_type' 	=> WPSD_POST_TYPE, 
							'post_status'	=> 'publish' , 
							'posts_per_page' => $pagelimit 
						);
		
		//get end deals days from settings page
		$ending_days = !empty( $ending_deals_in ) ? $ending_deals_in : 0;
		$ending_deals_days = date_i18n('Y-m-d H:i:s', strtotime('+'.$ending_days.' days'));
		$ending_deals_days = strtotime( $ending_deals_days );
		
		$endmetaquery = array( 
								array(
											'key' => '_wpsd_enable',
											'value' => '1',
											'compare' => '=',
											'type' => 'STRING'
										),
								array ( 	
											'key' => '_sale_price_dates_to',
											'value' => $ending_deals_days,
											'compare' => '<=',
											'type' => 'STRING'
										),
								array ( 	
											'key' => '_sale_price_dates_from',
											'value' => $today,
											'compare' => '<=',
											'type' => 'STRING'
										),
								array ( 	
											'key' => '_sale_price_dates_to',
											'value' => $today,
											'compare' => '>=',
											'type' => 'STRING'
										)
						 );
							 
		$argsend = array_merge( $homeargs, array( 'meta_query'	=> $endmetaquery ) );
						 
		if( isset( $category ) && !empty( $category ) ) { //check category id is set or not
			$args_end[WPSD_POST_TAXONOMY] = $category;
		}
		
		//ending deals template
		wpsd_get_template( 'home/home-content/more-deals.php', array( 'args' => $argsend, 'tab' => 'ending-soon' ) );
	}
}

if( !function_exists( 'wpsd_home_more_deal_upcoming' ) ) {
	/**
	 * Load Home Content Upcoming Deals Template
	 * 
	 * Handles to home page upcoming 
	 * deals template 
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */	
	function wpsd_home_more_deal_upcoming( $category ) {
		
		$today = date_i18n('Y-m-d H:i:s');
		$today = strtotime( $today );
			
		$deals_per_page = get_option('deals_per_page');
		$upcoming_deals_in = get_option('upcoming_deals_in');
		
		//get page limit from plugin settings page
		$pagelimit = isset($deals_per_page) ? $deals_per_page : -1;
		
		$homeargs = array(  
							'post_type' 	=> WPSD_POST_TYPE, 
							'post_status'	=> 'publish' , 
							'posts_per_page' => $pagelimit 
						);
						
		//get upcoming deals days from settings page
		$upcoming_days = !empty($upcoming_deals_in) ? $upcoming_deals_in : 0;
		$upcoming_deal_days = date_i18n('Y-m-d H:i:s', strtotime('+'.$upcoming_days.' days'));
		$upcoming_deal_days = strtotime( $upcoming_deal_days );
		
		$upcomingmetaquery = array( 
									array(
												'key' => '_wpsd_enable',
												'value' => '1',
												'compare' => '=',
												'type' => 'STRING'
											),
									array ( 	
												'key' 		=> '_sale_price_dates_from',
												'value'		=> $upcoming_deal_days,
												'compare'	=> '<=',
												'type' 		=> 'STRING'
											),
									
									array(		
												'key' 		=> '_sale_price_dates_from',
												'value' 	=> $today,
												'compare' 	=> '>',
												'type' 		=> 'STRING'
										)
								 );
		
		$argsupcoming = array_merge( $homeargs, array( 'meta_query' => $upcomingmetaquery ) );
		
		if( isset( $category ) && !empty( $category ) ) { //check category id is set or not
			$argsupcoming[WPSD_POST_TAXONOMY] = $category;
		}
		
		//upcoming deals template
		wpsd_get_template( 'home/home-content/more-deals.php', array( 'args' => $argsupcoming, 'tab' => 'upcoming-soon' ) );

	}
}

if( !function_exists( 'wpsd_home_header_content' ) ) {
	/**
	 * Load Home Page Header Left Content Template
	 * 
	 * Handles to load home page header 
	 * left side content
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */	
	function wpsd_home_header_content() {
		
		global $post,$wpsd_price,$product;
	
		// get the value for deal price from the post meta box
		$normalprice = $wpsd_price->wpsd_get_normal_price();
		
		// get the value for deal sale price from the post meta box
		$saleprice = $product->get_price();
	
		//product price
		$productprice = $wpsd_price->wpsd_get_price($normalprice,$saleprice);
		
		// get the value for the deal main image from the post meta box		
		$deal_image = $deal_main_image = get_post_meta( $post->ID, '_wpsd_main_image', true );
		
		$dealimg = !empty( $deal_image['src'] ) ? $deal_image['src'] : WPSD_IMG_URL.'/deals-no-image-big.jpg';
		
		$args = array( 
						'dealtitle'		=>	get_the_title( $post->ID ),
						'dealimg'		=>	$dealimg,
						'price'			=>	$wpsd_price->wpsd_get_display_price( $productprice ),
						'dealurl'		=>	get_permalink($post->ID),
						'description'	=>	get_the_excerpt()
					);
		
		//home page header deal left content template
		wpsd_get_template( 'home/home-header/header-content.php', $args );
	}
}

if( !function_exists( 'wpsd_home_header_timer' ) ) {
	/**
	 * Load Home Page End Deal Timer Template
	 * 
	 * Handles to load home page end deal timer
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */	
	function wpsd_home_header_timer() {
		
		global $post,$wpsd_model;
		
		// get the value for the deal end date from the post meta box
		$enddate = $wpsd_model->wpsd_get_end_date( $post->ID );
		
		if(!empty($enddate)) { //check deal end date 
			
			$countdowntimer = $wpsd_model->wpsd_getting_countdown_script($enddate);
			echo $countdowntimer;
			
		}
		
		//show home page header timer template
		wpsd_get_template( 'home/home-header/header-timer.php' );
		
	}
}


if( !function_exists( 'wpsd_home_header_discount' ) ) {
	/**
	 * Load Home Page Deal Discount Box Template
	 * 
	 * Handles to load home page deal discount box template
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	function wpsd_home_header_discount() {
		
		global $post,$wpsd_price,$product;
		
		// get the value for deal price from the post meta box
		$normalprice = $wpsd_price->wpsd_get_normal_price();
		
		// get the value for deal sale price from the post meta box
		$saleprice = $product->get_price();
	
		//discount 
		$discount = $wpsd_price->wpsd_get_discount($normalprice,$saleprice);
		
		//show home page header discount templage
		wpsd_get_template( 'home/home-header/header-discount.php', array( 'discount' => $discount ) );
		
	}
}

if( !function_exists( 'wpsd_home_header_dealvalue' ) ) {
	
	/**
	 * Load Home Page Deal Value Template
	 * 
	 * Handles to load home page deal value
	 * template
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	function wpsd_home_header_dealvalue() {
		
		global $post,$wpsd_price,$product;
	
		// get the value for deal price from the post meta box
		$normalprice = $wpsd_price->wpsd_get_normal_price();
		
		$displaynormalprice = $wpsd_price->wpsd_get_display_price( $normalprice );
			
		//show home page header deal value template
		wpsd_get_template( 'home/home-header/header-value.php', array( 'normalprice' => $displaynormalprice ) );
		
	}
}

if( !function_exists( 'wpsd_home_header_dealsave' ) ) {
	/**
	 * Load Home Page Deal Saving Price Box Template
	 * 
	 * Handles to load home page deal saving price
	 * box template
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	function wpsd_home_header_dealsave() {
		
		global $post,$wpsd_price,$product;
	
		// get the value for deal price from the post meta box
		$normalprice = $wpsd_price->wpsd_get_normal_price();
		
		// get the value for deal sale price from the post meta box
		$saleprice = $product->get_price();
	
		//saving price
		$yousave = $wpsd_price->wpsd_get_savingprice($normalprice,$saleprice);
		
		//show home page header saving price box template
		wpsd_get_template( 'home/home-header/header-save.php', array( 'savingprice' => $yousave ) );
		
	}
}

if( !function_exists( 'wpsd_home_header_ratings' ) ) {
	/**
	 * Load Home Page Ratings Template
	 * 
	 * Handles to load home page ratings 
	 * template
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	function wpsd_home_header_ratings() {
		
		if( class_exists( 'Wps_Fbre_Model' ) ) { // check if the social review engine plugin is activated
	
			global $wps_fbre_model,$post;
			
			$rating = round( $wps_fbre_model->wps_fbre_post_average_ratings( $args = array( 'post_id' => $post->ID ) ) );
		
			//show home page header ratings template
			wpsd_get_template( 'home/home-header/ratings.php', array( 'rating' => $rating ) );
		}
	}
}

if( !function_exists( 'wpsd_social_sharing' ) ) {
	/**
	 * Load Social Sharing Link Template
	 * 
	 * Handles to show sharing link
	 * template
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	function wpsd_social_sharing() {
		
		global $post;
		
		$sharing_discount_link_title = get_post_meta( $post->ID, '_wpsd_sharing_discount_link_title', true );
		$sharing_discount_title = get_post_meta( $post->ID, '_wpsd_sharing_discount_title', true );
		$sharing_discount_content = get_post_meta( $post->ID, '_wpsd_sharing_discount_content', true );
	
		//check sharing discount link title not empty
		if( !empty( $sharing_discount_link_title ) ) {
			
			$args = array( 
							'dealid'				=>	$post->ID,
							'discount_link_title'	=>	$sharing_discount_link_title, 
							'discount_title'		=>	$sharing_discount_title,
							'discount_content'		=>	$sharing_discount_content
						);
			
			//social button facebook template
			wpsd_get_template( 'social-buttons/sharing-link.php', $args );
		}
	}
	
}

if( !function_exists( 'wpsd_social_facebook' ) ) {
	/**
	 * Load Social Facebook Button Template
	 * 
	 * Handles to show facebook button
	 * template
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	function wpsd_social_facebook() {
		
		global $post;
		
		$facebook_button = get_option('social_buttons_facebook');
	
		//check facebook button is enable or not
		if( isset($facebook_button) && $facebook_button == 'yes' )  {
			
			//social button facebook template
			wpsd_get_template( 'social-buttons/facebook.php', array( 'dealurl' => get_permalink( $post->ID ), 'dealid' => $post->ID ) );
		}
	}
	
}

if( !function_exists( 'wpsd_social_twitter' ) ) {
	/**
	 * Load Social Twitter Button Template
	 * 
	 * Handles to load twitter button
	 * template
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	function wpsd_social_twitter() {
		
		global $post;
		
		$tw_user_name = get_option('tw_user_name');
		$twitter_button = get_option('social_buttons_twitter');
	
		//check twitter button is enable or not
		if( isset($twitter_button) && $twitter_button == 'yes' )  {
			
			$twitteruser = !empty($tw_user_name) ? $tw_user_name : '';
			
			$args = array( 
							'dealurl'	=>	get_permalink( $post->ID ), 
							'dealid'	=>	$post->ID,
							'dealtitle'	=>	get_the_title( $post->ID ),
							'twitteruser' => $twitteruser 
						);
							
			//social button twitter template
			wpsd_get_template( 'social-buttons/twitter.php', $args );
		}
	}
	
}

if( !function_exists( 'wpsd_social_google' ) ) {
	
	/**
	 * Load Social Google+ Button Template
	 * 
	 * Handles to load google+ button
	 * template
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	function wpsd_social_google() {
		
		global $post;
		
		$google_button = get_option('social_buttons_google');
	
		//check google button is enable or not
		if( isset($google_button) && $google_button == 'yes' )  {
			
			$args = array( 
							'dealurl'	=>	get_permalink( $post->ID ), 
							'dealid'	=>	$post->ID
						);
							
			//social google+ button template
			wpsd_get_template( 'social-buttons/google.php', $args );
		}
	}
	
}

if( !function_exists( 'wpsd_social_fanpage' ) ) {
	
	/**
	 * Load Social Fanpage Button Template
	 * 
	 * Handles to load fanpage button
	 * template
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	function wpsd_social_fanpage() {
		
		global $post;
		
		$fanpage_button = get_option('social_buttons_fanpage');
		$fan_page_url = get_option('fan_page_url');
	
		//check fanpage button is enable or not
		if( isset($fanpage_button) && $fanpage_button == 'yes' && !empty($fan_page_url) )  {
			
			$args = array( 
							'dealurl'	=>	get_permalink( $post->ID ), 
							'dealid'	=>	$post->ID,
							'fanpageurl'=>	$fan_page_url
						);
							
			//social fanpage button template
			wpsd_get_template( 'social-buttons/fanpage.php', $args );
		}
	}
	
}

if( !function_exists( 'wpsd_social_buttons' ) ) {
	/**
	 * Load Social Buttons Template
	 * 
	 * Handles to load social buttons
	 * template
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	function wpsd_social_buttons() {
		
		$disable_bootstrap = get_option('disable_twitter_bootstrap');
		if( empty($disable_bootstrap) || $disable_bootstrap == 'no' ) {
			wp_enqueue_script('wpsd-bootstrap-script');
		}
		
		//social buttons template
		wpsd_get_template( 'social-buttons/social-buttons.php' );
		
	}
}

if( !function_exists( 'wpsd_home_header_see_deal' ) ) {
	/**
	 * Load Big See Deal Button Template
	 * 
	 * Handles to load big see deal button
	 * template
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */	
	function wpsd_home_header_see_deal() {
		
		//load big see deal button template
		wpsd_get_template( 'buttons/deal-button-big.php');
	}
}

if( !function_exists( 'wpsd_home_more_deal_price_flag' ) ) {
	/**
	 * Load Price Flag with Price Template
	 * 
	 * Handles to load price flag with price
	 * template
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */	
	function wpsd_home_more_deal_price_flag() {
		
		global $post,$wpsd_price,$product,$wpsd_model;
	
		// get the value for deal price from the post meta box
		$normalprice = $wpsd_price->wpsd_get_normal_price();
		
		// get the value for deal sale price from the post meta box
		//$saleprice = $product->get_price();
		$saleprice = $wpsd_price->wpsd_get_future_sale_price();
		
		//product price
		$dealprice = $wpsd_price->wpsd_get_price( $normalprice, $saleprice );
		$displayprice = $wpsd_price->wpsd_get_display_price( $dealprice );
		
		//price flag with price template
		wpsd_get_template( 'home/home-content/price-flag-small.php', array( 'displayprice' => $displayprice ) );
		
	}
}

if( !function_exists( 'wpsd_home_more_deal_image' ) ) {
	/**
	 * Load More Deal Image Template for Home Page
	 * 
	 * Handles to load more deal image template
	 * for home page
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	
	function wpsd_home_more_deal_image() {
		
		global $post;

		// get the value for the deal main image from the post meta box		
		$deal_image = $deal_main_image = get_post_meta( $post->ID, '_wpsd_main_image', true );
		
		$dealimg = !empty( $deal_image['src'] ) ? $deal_image['src'] : WPSD_IMG_URL.'/deals-no-image-big.jpg';
		
		//more deals deal image template
		wpsd_get_template( 'home/home-content/deal-image.php', array( 'dealimg' => $dealimg, 'dealurl'  => get_permalink( $post->ID ), 'dealtitle' => get_the_title($post->ID) ) );
	}
}

if( !function_exists( 'wpsd_home_more_deal_normal_price' ) ) {
	/**
	 * Load Normal Priec Template
	 * 
	 * Handles to load normal price template
	 * to show deal normal price
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	function wpsd_home_more_deal_normal_price() {
		
		global $post,$wpsd_price,$product,$wpsd_model;
	
		// get the value for deal price from the post meta box
		$normalprice = $wpsd_price->wpsd_get_normal_price();
		
		$displaynormalprice = $wpsd_price->wpsd_get_display_price( $normalprice );
		
		//deal normal price template
		wpsd_get_template( 'home/home-content/deal-value.php', array( 'normalprice' => $displaynormalprice ) );
	
	}
}

if( !function_exists( 'wpsd_home_more_deal_discount' ) ) {
	/**
	 * Load Deal Discount Template
	 * 
	 * Handles to load deal discount template
	 * in home page more deals
	 *  
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	function wpsd_home_more_deal_discount() {
		
		global $post,$wpsd_price,$product,$wpsd_model;
	
		// get the value for deal price from the post meta box
		$normalprice = $wpsd_price->wpsd_get_normal_price();
		
		// get the value for deal sale price from the post meta box
		//$saleprice = $product->get_price();
		$saleprice = $wpsd_price->wpsd_get_future_sale_price();
				
		//discount 
		$discount = $wpsd_price->wpsd_get_discount( $normalprice, $saleprice );
		
		//deal discount template
		wpsd_get_template( 'home/home-content/deal-discount.php', array( 'discount' => $discount ) );
	}
}

if( !function_exists( 'wpsd_home_more_deal_saving' ) ) {
	/**
	 * Load Deal Saving Price Template
	 * 
	 * Handles to load deal saving price template
	 * in home page more deals
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	function wpsd_home_more_deal_saving() {
		
		global $post,$wpsd_price,$product,$wpsd_model;
	
		// get the value for deal price from the post meta box
		$normalprice = $wpsd_price->wpsd_get_normal_price();
		
		// get the value for deal sale price from the post meta box
		//$saleprice = $product->get_price();
		$saleprice = $wpsd_price->wpsd_get_future_sale_price();
			
		//saving price
		$yousave = $wpsd_price->wpsd_get_savingprice( $normalprice, $saleprice );
		
		//show deal image on home page content
		wpsd_get_template( 'home/home-content/deal-save.php', array( 'savingprice' => $yousave ) );
	}
}

if( !function_exists( 'wpsd_home_more_deal_footer_time' ) ) {
	
	/**
	 * Load Deal End Timer Template
	 * 
	 * Handles to load deal end timer template
	 * in home page more deals
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	function wpsd_home_more_deal_footer_time() {
		
		global $post,$wpsd_model;
	
		//now time
		$today = date_i18n('Y-m-d H:i:s');
	
		// get the value for the deal end date from the post meta box
		$deal_end_date = $wpsd_model->wpsd_get_end_date( $post->ID );
						
		$difference = strtotime($deal_end_date) - strtotime($today);
		
		$datediff = $wpsd_model->wpsd_seconds_to_time($difference);
		
		//deal timer template
		wpsd_get_template( 'home/home-content/timer.php', array( 'timeremain' => $datediff ) );
	}
}

if( !function_exists( 'wpsd_home_more_deal_footer_see_deal' ) ) {
	
	/**
	 * Load Small See Deal Button Template
	 * 
	 * Handles to load small see deal button
	 * template in home page more deals
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	
	function wpsd_home_more_deal_footer_see_deal() {
		
		global $post;
		
		//show deal image on home page content
		wpsd_get_template( 'buttons/deal-button-small.php', array( 'dealurl' => get_permalink($post->ID) ) );
	}
}

/*************************** Single Deals Header Right Page Template ******************************/

if( !function_exists( 'wpsd_single_dimsale_box' ) ) {
	
	/**
	 * Load Single Deal Dimsale Box Template
	 * 
	 * Handles to load single deal dimsale
	 * box template
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	function wpsd_single_dimsale_box() {
		
		global $post, $product, $wpsd_model;
		
		//today's date time
		$today = date_i18n('Y-m-d H:i:s');
		
		//get the value for available deals from the post meta box
		$available = $product->get_total_stock();
		
		//get the value for start date & time of deals from the post meta box
		$startdate = $wpsd_model->wpsd_get_start_date( $post->ID );
		
		//get the value for end date & time of deals from the post meta box
		$enddate = $wpsd_model->wpsd_get_end_date( $post->ID );
		
		//when deal expired
		$dealexpired = false;
	
		if ( $available == '' ) {} //check availble  is empty or not
		elseif ( intval( $available ) == 0 ) { $dealexpired = true; } 
		else {}
		
		//get dimsale ratio
		$dimsaleratio = get_post_meta( $post->ID, '_wpsd_inc_ratio', true );
		
		//get dimsale price 
		$dimsaleprice = get_post_meta( $post->ID, '_wpsd_inc_price', true );
		
		//get dimsale is activated
		$dimsaleamt = get_post_meta($post->ID, '_wpsd_nxt_inc_period', true);
	
		$lefttext = '';
		
		if(!empty( $dimsaleprice ) && !empty( $dimsaleratio ) ) {
			$leftcopies = ( $dimsaleratio - $dimsaleamt );
			$lefttext = sprintf( __('Only %1$s left at this price', 'wpsd' ), $leftcopies ); 
		}
		
		if( $enddate >= $today && $dealexpired != true ) {
			
			//dim sale box template
			wpsd_get_template( 'single-deal/single-header/dime-sale.php', array( 'lefttext' => $lefttext ) );
		}
		
	}
	
}

if( !function_exists( 'wpsd_single_deal_details' ) ) {
	
	/**
	 * Load Single Deal Details Template 
	 * 
	 * Handles to load single deal details
	 * template
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	function wpsd_single_deal_details() {
		
		global $product, $wpsd_model;
		//check product type is not grouped
		if( strtolower($product->product_type) != 'grouped' ) {
			
			$size = get_option('deals_size');
			$display_none = '';
			
			$variation_id = $wpsd_model->wpsd_get_default_variation_id();
			
			if( empty($variation_id) && strtolower($product->product_type) == 'variable' ) {
				$display_none = 'wpsd-display-none';
			} 
			
			//deal details template
			wpsd_get_template( 'single-deal/single-header/deal-details.php', array( 'size' => $size, 'display_none' => $display_none ) );
		}
		
	}
	
}

if( !function_exists( 'wpsd_single_deal_timer' ) ) {
	
	/**
	 * Load Single Deal Timer Template
	 * 
	 * Handles to load single deal timer 
	 * template
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	function wpsd_single_deal_timer() {
		
		global $post,$wpsd_model;
		
		//today's date time
		$today = date_i18n('Y-m-d H:i:s');
		
		//get the value for start date & time of deals from the post meta box
		$startdate = $wpsd_model->wpsd_get_start_date( $post->ID );
		
		//get the value for end date & time of deals from the post meta box
		$enddate = $wpsd_model->wpsd_get_end_date( $post->ID );
		
		if( $enddate >= $today ) { //check if the deal is still active
			
			if(!empty($enddate) || !empty($startdate)) { //check end date is not empty or startdate is not empty
				if($startdate >= $today) { // check startdate is greater than today 
					$counterdate = $startdate;
				} else {
					$counterdate = $enddate;
				}
				$countdowntimer = $wpsd_model->wpsd_getting_countdown_script($counterdate);
				echo $countdowntimer;
			}
			
			$args = array( 
							'startdate'	=>	$startdate, 
							'enddate'	=>	$enddate,
							'today'		=>	$today
						);
			
			//deal timer template
			wpsd_get_template( 'single-deal/single-header/deal-end-timer.php',  $args );
		}
		
	}
	
}

if( !function_exists( 'wpsd_single_normalprice' ) ) {
		
	/**
	 * Load Single Deal Normal Price Template
	 * 
	 * Handles to load single deal normal price
	 * template 
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	function wpsd_single_normalprice() {
		
		global $post, $wpsd_price, $wpsd_model;
		
		$variation_id = $wpsd_model->wpsd_get_default_variation_id();
		
		if( !empty($variation_id) ) {
			
			// get the value for variation normal price from the post meta box
			$normalprice = get_post_meta( $variation_id, '_regular_price', true );
			
		} else {
			
			// get the value for normal price from the post meta box
			$normalprice = $wpsd_price->wpsd_get_normal_price();
		}
		
		$displayprice = $wpsd_price->wpsd_get_display_price( $normalprice );
		
		//show normal value template
		wpsd_get_template( 'single-deal/single-header/deal-value.php', array( 'price' => $displayprice ) );
		
	}
}

if( !function_exists( 'wpsd_single_discount' ) ) {
		
	/**
	 * Load Single Deal Discount Template
	 * 
	 * Handles to load single deal discount
	 * template
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	function wpsd_single_discount() {
		
		global $post, $product, $wpsd_price, $wpsd_model;
		
		$variation_id = $wpsd_model->wpsd_get_default_variation_id();
		
		if( !empty($variation_id) ) {
			
			// get the value for variation normal price from the post meta box
			$normalprice = get_post_meta( $variation_id, '_regular_price', true );
			
			// get the value for variation sale price from the post meta box	
			$saleprice = get_post_meta( $variation_id, '_price', true );
			
		} else {
				
			// get the value for normal price from the post meta box	
			$normalprice = $wpsd_price->wpsd_get_normal_price();
			
			// get the value for sale price from the post meta box	
			//$saleprice = $product->get_price();
			$saleprice = $wpsd_price->wpsd_get_future_sale_price();
		}
			
		//discount 
		$discount = $wpsd_price->wpsd_get_discount( $normalprice, $saleprice );
		
		//show deal discount template
		wpsd_get_template( 'single-deal/single-header/deal-discount.php', array( 'discount' => $discount ) );
		
	}
}
if( !function_exists( 'wpsd_single_save' ) ) {
		
	/**
	 * Load Single Deal Saving Price Template
	 * 
	 * Handles to show single deal saving 
	 * price template
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	function wpsd_single_save() {
		
		global $post, $product, $wpsd_price, $wpsd_model;
		
		$variation_id = $wpsd_model->wpsd_get_default_variation_id();
		
		if( !empty($variation_id) ) {
			
			// get the value for variation normal price from the post meta box
			$normalprice = get_post_meta( $variation_id, '_regular_price', true );
			
			// get the value for variation sale price from the post meta box	
			$saleprice = get_post_meta( $variation_id, '_price', true );
			
		} else {
			
			// get the value for normal price from the post meta box	
			$normalprice = $wpsd_price->wpsd_get_normal_price(); 
			
			// get the value for sale price from the post meta box	
			//$saleprice = $product->get_price();
			$saleprice = $wpsd_price->wpsd_get_future_sale_price();
		}
		
		//saving price
		$yousave = $wpsd_price->wpsd_get_savingprice( $normalprice, $saleprice );	
		
		//show deal saving price template
		wpsd_get_template( 'single-deal/single-header/deal-save.php', array( 'savingprice' => $yousave ) );
		
	}
}

if( !function_exists( 'wpsd_single_deal_avail_bought' ) ) {
	
	/**
	 * Load Single Deal Available & Bought Box Template
	 * 
	 * Handles to load single deal available & bought
	 * box tempalte
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	function wpsd_single_deal_avail_bought() {
		
		global $post, $product, $wpsd_model;
		 
		//today's date time
		$today = date_i18n('Y-m-d H:i:s');
		$display_none = '';
			
		$variation_id = $wpsd_model->wpsd_get_default_variation_id();
		
		if( empty($variation_id) && strtolower($product->product_type) == 'variable' ) {
			$display_none = 'wpsd-display-none';
		}
		
		//get the value for end date & time of deals from the post meta box
		$enddate = $wpsd_model->wpsd_get_end_date( $post->ID );
		
		//get the available_bought value from the meta box
		$available_bought = get_post_meta($post->ID,'_wpsd_available_bought',true);
		
		if( $enddate >= $today ) { //check if the deal is still active
				
			//available and bought box template
			wpsd_get_template( 'single-deal/single-header/avail-bought.php', array( 'availablebought' => $available_bought, 'display_none' => $display_none ) );
			
		}
	}
	
}

if( !function_exists( 'wpsd_single_available' ) ) {
		
	/**
	 * Load Single Deal Available Box Template
	 * 
	 * Handles to show single deal available box
	 * template
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	function wpsd_single_available() {
		
		global $post, $product, $wpsd_model;
		
		$variation_id = $wpsd_model->wpsd_get_default_variation_id();
		
		if( !empty($variation_id) ) {
			
			//get the value for variation available deals from the post meta box
			$available = get_post_meta( $variation_id, '_stock', true );
			
			if( $available == 0 ) {
				$available =  __('Out of Stock','wpsd');
			} else if( empty($available) ) {
				$available =  __('Unlimited','wpsd');
			}
			
		} else {
			
			//get the value for available deals from the post meta box
			$available = $product->get_total_stock();
		
			$avail_stock = $product->is_in_stock();
			$manage_stock = $product->managing_stock();
			
			//check stock is availabel or not
			if ( !$avail_stock ) {
				$available =  __('Out of Stock','wpsd');
			} elseif ( !$manage_stock ) {
				//if manag stock is not set
				$available =  __('Unlimited','wpsd');
			}
		}
		
		//show deal available template
		wpsd_get_template( 'single-deal/single-header/avail-bought/available.php', array( 'available' => $available ) );
		
	}
}
if( !function_exists( 'wpsd_single_bought' ) ) {
		
	/**
	 * Load Single Deal Bought Box Template
	 * 
	 * Handles to load single deal bought box
	 * template
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	function wpsd_single_bought() {
		
		global $post;
		
		//get the value for bought deals from the post meta box
		$boughts = get_post_meta($post->ID,'total_sales',true);
		$boughts = isset($boughts) && !empty($boughts) ? $boughts : '0';
	
		//bought box template
		wpsd_get_template( 'single-deal/single-header/avail-bought/bought.php', array( 'bought' => $boughts ) );
	}
}

/*************************** Single Deals Footer Page Template ******************************/

if( !function_exists( 'wpsd_single_business_title' ) ) {
		
	/**
	 * Load Single Business Title Template
	 * 
	 * Handles to single deal business title
	 * template
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	function wpsd_single_business_title() {
		
		global $post;
		
		// get the business title from the post meta box
		$businesstitle = get_post_meta($post->ID,'_wpsd_business_title',true);
	
		//business title template
		if( !empty( $businesstitle ) ) { //check business title is not empty
			wpsd_get_template( 'single-deal/single-footer/business-title.php', array( 'businesstitle' => $businesstitle ) );
		}
	}
}
if( !function_exists( 'wpsd_single_business_location' ) ) {
		
	/**
	 * Load Single Deal Business Location Map Template
	 * 
	 * Handles to load single deal business
	 * location map template
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	function wpsd_single_business_location() {
		
		global $post;
	
		//show google map
		$gmapaddress = get_post_meta( $post->ID, '_wpsd_map_address', true );
		$address = str_replace("'", "&prime;", $gmapaddress);
		
		if( !empty( $address ) ) { //check business title is not empty
			
			wp_enqueue_script('wpsd-google-map');
			wp_enqueue_script('wpsd-map-script');
		
			//business location map templatte	
			wpsd_get_template( 'single-deal/single-footer/business-location-map.php' );
			
		}
	}
}
if( !function_exists( 'wpsd_single_business_logo' ) ) {
		
	/**
	 * Load Single Deal Business Logo Template
	 * 
	 * Handles to single deal business logo
	 * template
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	function wpsd_single_business_logo() {
		
		global $post;
	
		// get the business logo from the post meta box
		$business_logo = get_post_meta($post->ID,'_wpsd_business_logo',true);
		
		
		if( !empty( $business_logo['src'] ) ) { //check business title is not empty
			
			//business logo template
			wpsd_get_template( 'single-deal/single-footer/business-logo.php', array( 'imgurl' => $business_logo['src'] ) );
			
		}
	}
}
if( !function_exists( 'wpsd_single_business_address' ) ) {
		
	/**
	 * Load Single Deal Business Address Template
	 * 
	 * Handles to load single deal business address
	 * template
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	function wpsd_single_business_address() {
		
		global $post;
	
		// get the business address from the post meta box
		$business_address = get_post_meta($post->ID,'_wpsd_business_address',true);
		
		
		if( !empty( $business_address ) ) { //check business title is not empty
			
			//business address template	
			wpsd_get_template( 'single-deal/single-footer/business-address.php', array( 'address' => $business_address ) );
			
		}
	}
}
if( !function_exists( 'wpsd_single_business_link' ) ) {
		
	/**
	 * Load Single Deal Business Link Template 
	 * 
	 * Handles to load single deal business
	 * link template
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	function wpsd_single_business_link() {
		
		global $post;
	
		//get the value for business URL of deal from the post meta box
		$business_url = get_post_meta($post->ID,'_wpsd_business_web_url',true);
		
		
		if( !empty( $business_url ) ) { //check business title is not empty
			
			//business link template	
			wpsd_get_template( 'single-deal/single-footer/business-link.php', array( 'businesslink' => $business_url ) );
			
		}
	}
}
if( !function_exists( 'wpsd_single_terms_conditions' ) ) {
		
	/**
	 * Load Single Deal Terms & Condition Template
	 * 
	 * Handles to load single deal terms & condition
	 * template
	 * 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	function wpsd_single_terms_conditions() {
		
		global $post;
	
		$disable_bootstrap = get_option('disable_twitter_bootstrap');
		if( empty($disable_bootstrap) || $disable_bootstrap == 'no' ) {
			wp_enqueue_script('wpsd-bootstrap-script');
		}
		
		//get the value for terms and conditions of deals from the post meta box
		$termsconditions = get_post_meta($post->ID,'_wpsd_term_cond',true );
		
		if( !empty( $termsconditions ) ) { //check terms and conditions
			
			//terms and conditions template	
			wpsd_get_template( 'single-deal/single-footer/terms.php', array( 'termsconditions' => $termsconditions ) );
			
		}
	}
}