<?php
/**
 * Plugin Name: WooCommerce Social Deals
 * Plugin URI: http://wpsocial.com/product/woocomerce-social-deals/
 * Description: Extends WooCommerce to create Deals from products.
 * Version: 1.0.0
 * Author: WPSocial.com
 * Author URI: http://wpsocial.com
 *
 * Copyright 2013 WPSocial.com  (email : info@wpsocial.com)
 */

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

/**
 * Check if WooCommerce is active
 * 
 * @package WooCommerce WP Social Deals
 * @since 1.0.0
 **/
if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
	
	/**
	 * Basic plugin definitions 
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	global $wpdb;
	
	if( !defined( 'WPSD_VERSION' ) ) {
		define( 'WPSD_VERSION', '1.0.0' ); // plugin version
	}
	if( !defined( 'WPSD_DIR' ) ) {
		define( 'WPSD_DIR', dirname( __FILE__ ) ); // plugin dir
	}
	if( !defined( 'WPSD_URL' ) ) {
		define( 'WPSD_URL', plugin_dir_url( __FILE__ ) ); // plugin url
	}
	if( !defined( 'WPSD_ADMIN_DIR' ) ) {
		define( 'WPSD_ADMIN_DIR', WPSD_DIR . '/includes/admin' ); // plugin admin dir
	}
	if( !defined( 'WPSD_IMG_URL' ) ) {
		define( 'WPSD_IMG_URL', WPSD_URL.'includes/images' ); // plugin admin dir
	}
	if( !defined( 'WPSD_POST_TYPE' ) ) {
		define( 'WPSD_POST_TYPE', 'product' ); //woocommerce post type
	}
	if( !defined( 'WPSD_PLUGIN_BASENAME' ) ) {
		define( 'WPSD_PLUGIN_BASENAME', 'woocommerce_wpsocial_deals' ); //Plugin base name
	}
	
	/**
	 * Load Text Domain
	 *
	 * This gets the plugin ready for translation.
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	function wpsd_load_textdomain() {
	
	  load_plugin_textdomain( 'wpsd', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
	
	}
	
	add_action( 'init', 'wpsd_load_textdomain' );
		
	/**
	 * Activation Hook
	 *
	 * Register plugin activation hook.
	 *
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	register_activation_hook( __FILE__, 'wpsd_install' );
	
	/**
	 * Deactivation Hook
	 *
	 * Register plugin deactivation hook.
	 *
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	register_deactivation_hook( __FILE__, 'wpsd_uninstall');
	
	/**
	 * Plugin Setup (On Activation)
	 *
	 * Does the initial setup,
	 * stest default values for the plugin options.
	 *
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	function wpsd_install() {
		
		global $wpdb,$user_ID;
		
		//get option for when plugin is activating first time
		$wpsd_set_option = get_option('wpsd_set_option');
		
		if( empty( $wpsd_set_option ) ) { //check plugin version option
			
			$deals_page = array(
									'post_type' 	=> 'page',
									'post_status' 	=> 'publish',
									'post_title' 	=> __('Deals','wpsd'),
									'post_content' 	=> '[wpsd_woo_deals][/wpsd_woo_deals]',
									'post_author' 	=> $user_ID,
									'menu_order' 	=> 0,
									'comment_status' => 'closed'
								);
								
			//create main page for plugin					
			$deals_parent_page_id = wp_insert_post($deals_page);
			
			// this option contains all page ID(s) to just pass it to wpsd_default_settings function
			update_option('wpsd_set_pages', array(
														'main_page'	=> 	$deals_parent_page_id
													));
			
			//update default options
			wpsd_default_settings();
			
			//update plugin version to option 
			update_option('wpsd_set_option','1.0');
											
		}
		
		$wpsd_set_option = get_option('wpsd_set_option');
		
		if( $wpsd_set_option == '1.0' ) { //check set option for plugin is set 1.0
			
			update_option( 'deals_caching', 'no' );
			
			//update plugin version to option 
			update_option('wpsd_set_option','1.0.1');
		}
		
		$wpsd_set_option = get_option('wpsd_set_option');
		
		if( $wpsd_set_option == '1.0.1' ) {
		
			// future code will be done here
		}
	}
	
	/**
	 * Plugin Setup (On Deactivation)
	 *
	 * Delete  plugin options.
	 *
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	function wpsd_uninstall() {
	
		global $wpdb;
			
	}
	
	/**
	 * Plugin Setup (On First Time Activation)
	 *
	 * Does the initial setup when plugin is going to activate first time,
	 * stest default values for the plugin options.
	 *
	 * @package WooCommerce WP Social Deals
	 * @since 1.0.0
	 */
	
	function wpsd_default_settings() {
		
		//get values for created pages
		$pages = get_option('wpsd_set_pages');
		
		$mainpage = '';
		if (isset($pages['main_page'])) { //check if checkout page is created then set to default
			$mainpage = $pages['main_page'];
		}
		$options = array(
							'deals_caching'				=>	'no',
							'deals_main_page'			=> $mainpage,
							'deals_size'				=>	'large',
							'disable_twitter_bootstrap'	=>	'no',
							'disable_more_deals'		=>	'no',
							'ending_deals_in'			=>	'5',
							'upcoming_deals_in'			=>	'5',
							'deals_per_page'			=>	'10',
							'social_buttons_facebook'	=>	'yes',
							'social_buttons_twitter'	=>	'no',
							'social_buttons_google'		=>	'no',
							'social_buttons_fanpage'	=>	'no',
							'tw_user_name'				=>	'',
							'fan_page_url'				=>	''
						);

		foreach ($options as $key => $value) {
			update_option( $key, $value );
		}
	}

	//global variables
	global $wpsd_model,
			$wpsd_render,$wpsd_scripts;
			
	//Model class handles most of functionalities
	require_once( WPSD_DIR . '/includes/class-wpsd-model.php' );
	$wpsd_model = new Wpsd_Model();

	// Script Class to manage all scripts and styles
	require_once( WPSD_DIR . '/includes/class-wpsd-scripts.php' );
	$wpsd_scripts = new Wpsd_Scripts();
	Wpsd_Scripts::serve();

	//Currencies class handles most of functionalities of plugin
	include_once( WPSD_DIR . '/includes/class-wpsd-price.php' );
	$wpsd_price = new Wpsd_Price();

	//Render class handles most of functionalities related HTML
	require_once( WPSD_DIR . '/includes/class-wpsd-renderer.php' );
	$wpsd_render = new Wpsd_Renderer();

	//Shortcodes class for handling shortcodes
	require_once( WPSD_DIR . '/includes/class-wpsd-shortcodes.php' );
	Wpsd_Shortcodes::serve();

	//Public Class for handling frontside functionlities
	require_once( WPSD_DIR . '/includes/class-wpsd-public.php');
	Wpsd_Public::serve();

	//Admin class handles most of admin functionalities of plugin
	require_once( WPSD_ADMIN_DIR. '/class-wpsd-admin.php' );
	Wpsd_Admin::serve();
	
	// loads the Templates Functions file
	require_once ( WPSD_DIR . '/includes/wpsd-template-functions.php' );

	//Register Widget
	require_once( WPSD_DIR . '/includes/widgets/class-wpsd-lists.php');

	//Load Template Hook File
	require_once( WPSD_DIR . '/includes/wpsd-template-hooks.php' );

}
?>